@@ -15,15 +15,15 @@ import (
 	"google.golang.org/grpc/credentials"
 
 	events "github.com/docker/go-events"
-	agentutils "github.com/docker/swarmkit/agent/testutils"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/connectionbroker"
-	"github.com/docker/swarmkit/log"
-	"github.com/docker/swarmkit/remotes"
-	"github.com/docker/swarmkit/testutils"
-	"github.com/docker/swarmkit/xnet"
+	agentutils "github.com/moby/swarmkit/v2/agent/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/connectionbroker"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/remotes"
+	"github.com/moby/swarmkit/v2/testutils"
+	"github.com/moby/swarmkit/v2/xnet"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
