@@ -2,7 +2,6 @@ package testutils
 
 import (
 	"context"
-	"io/ioutil"
 	"net"
 	"os"
 	"path/filepath"
@@ -12,11 +11,11 @@ import (
 
 	"google.golang.org/grpc"
 
-	"github.com/docker/swarmkit/agent/exec"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/log"
+	"github.com/moby/swarmkit/v2/agent/exec"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/log"
 	"github.com/stretchr/testify/require"
 )
 
@@ -138,6 +137,10 @@ func (m *MockDispatcher) UpdateTaskStatus(context.Context, *api.UpdateTaskStatus
 	panic("not implemented")
 }
 
+func (m *MockDispatcher) UpdateVolumeStatus(context.Context, *api.UpdateVolumeStatusRequest) (*api.UpdateVolumeStatusResponse, error) {
+	panic("not implemented")
+}
+
 // Tasks keeps an open stream until canceled
 func (m *MockDispatcher) Tasks(_ *api.TasksRequest, stream api.Dispatcher_TasksServer) error {
 	<-stream.Context().Done()
@@ -231,7 +234,7 @@ func NewMockDispatcher(t *testing.T, secConfig *ca.SecurityConfig, local bool) (
 		cleanup func()
 	)
 	if local {
-		tempDir, err := ioutil.TempDir("", "local-dispatcher-socket")
+		tempDir, err := os.MkdirTemp("", "local-dispatcher-socket")
 		require.NoError(t, err)
 		addr = filepath.Join(tempDir, "socket")
 		l, err = net.Listen("unix", addr)
