@@ -2,12 +2,14 @@ package agent
 
 import (
 	"context"
+	"errors"
+	"net"
 	"testing"
 
-	"github.com/docker/swarmkit/agent/exec"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/log"
-	"github.com/sirupsen/logrus"
+	"github.com/moby/swarmkit/v2/agent/exec"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/stretchr/testify/assert"
 	bolt "go.etcd.io/bbolt"
 )
@@ -17,7 +19,7 @@ type testPublisherProvider struct {
 
 func (tpp *testPublisherProvider) Publisher(ctx context.Context, subscriptionID string) (exec.LogPublisher, func(), error) {
 	return exec.LogPublisherFunc(func(ctx context.Context, message api.LogMessage) error {
-			log.G(ctx).WithFields(logrus.Fields{
+			log.G(ctx).WithFields(log.Fields{
 				"subscription": subscriptionID,
 				"task.id":      message.Context.TaskID,
 				"node.id":      message.Context.NodeID,
@@ -28,17 +30,43 @@ func (tpp *testPublisherProvider) Publisher(ctx context.Context, subscriptionID
 		}, nil
 }
 
+func newFakeReporter(statuses statusReporterFunc, volumes volumeReporterFunc) Reporter {
+	return statusReporterCombined{
+		statusReporterFunc: statuses,
+		volumeReporterFunc: volumes,
+	}
+}
+
 func TestWorkerAssign(t *testing.T) {
 	db, cleanup := storageTestEnv(t)
 	defer cleanup()
 
+	pg := &testutils.FakePluginGetter{
+		Plugins: map[string]*testutils.FakePlugin{
+			"plugin-1": {
+				PluginName: "plugin-1",
+				PluginAddr: &net.UnixAddr{},
+			},
+			"plugin-2": {
+				PluginName: "plugin-2",
+				PluginAddr: &net.UnixAddr{},
+			},
+		},
+	}
+
 	ctx := context.Background()
-	executor := &mockExecutor{dependencies: NewDependencyManager()}
+	executor := &mockExecutor{dependencies: NewDependencyManager(pg)}
+
 	worker := newWorker(db, executor, &testPublisherProvider{})
-	reporter := statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
-		log.G(ctx).WithFields(logrus.Fields{"task.id": taskID, "status": status}).Info("status update received")
-		return nil
-	})
+	reporter := newFakeReporter(
+		statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
+			log.G(ctx).WithFields(log.Fields{"task.id": taskID, "status": status}).Info("status update received")
+			return nil
+		}),
+		volumeReporterFunc(func(ctx context.Context, volumeID string) error {
+			return nil
+		}),
+	)
 
 	worker.Listen(ctx, reporter)
 
@@ -48,6 +76,7 @@ func TestWorkerAssign(t *testing.T) {
 		expectedSecrets  []*api.Secret
 		expectedConfigs  []*api.Config
 		expectedAssigned []*api.Task
+		expectedVolumes  []*api.VolumeAssignment
 	}{
 		{}, // handle nil case.
 		{
@@ -76,6 +105,14 @@ func TestWorkerAssign(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionUpdate,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionUpdate,
+				},
 				// these should be ignored
 				{
 					Assignment: &api.Assignment{
@@ -101,6 +138,14 @@ func TestWorkerAssign(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionRemove,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionRemove,
+				},
 			},
 			expectedTasks: []*api.Task{
 				{ID: "task-1"},
@@ -114,6 +159,9 @@ func TestWorkerAssign(t *testing.T) {
 			expectedAssigned: []*api.Task{
 				{ID: "task-1"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+			},
 		},
 		{ // completely replaces the existing tasks and secrets
 			changeSet: []*api.AssignmentChange{
@@ -141,6 +189,14 @@ func TestWorkerAssign(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionUpdate,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionUpdate,
+				},
 			},
 			expectedTasks: []*api.Task{
 				{ID: "task-2"},
@@ -155,6 +211,9 @@ func TestWorkerAssign(t *testing.T) {
 				// task-1 should be cleaned up and deleted.
 				{ID: "task-2"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+			},
 		},
 		{
 			// remove assigned tasks, secret and config no longer present
@@ -194,6 +253,11 @@ func TestWorkerAssign(t *testing.T) {
 			assert.NoError(t, err)
 			assert.NotNil(t, config)
 		}
+		for _, volume := range testcase.expectedVolumes {
+			_, err := executor.Volumes().Get(volume.VolumeID)
+			assert.Error(t, err)
+			assert.True(t, errors.Is(err, exec.ErrDependencyNotReady))
+		}
 	}
 }
 
@@ -202,12 +266,28 @@ func TestWorkerWait(t *testing.T) {
 	defer cleanup()
 
 	ctx := context.Background()
-	executor := &mockExecutor{dependencies: NewDependencyManager()}
+
+	pg := &testutils.FakePluginGetter{
+		Plugins: map[string]*testutils.FakePlugin{
+			"plugin-1": {
+				PluginName: "plugin-1",
+				PluginAddr: &net.UnixAddr{},
+			},
+		},
+	}
+
+	executor := &mockExecutor{dependencies: NewDependencyManager(pg)}
+
 	worker := newWorker(db, executor, &testPublisherProvider{})
-	reporter := statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
-		log.G(ctx).WithFields(logrus.Fields{"task.id": taskID, "status": status}).Info("status update received")
-		return nil
-	})
+	reporter := newFakeReporter(
+		statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
+			log.G(ctx).WithFields(log.Fields{"task.id": taskID, "status": status}).Info("status update received")
+			return nil
+		}),
+		volumeReporterFunc(func(ctx context.Context, volumeID string) error {
+			return nil
+		}),
+	)
 
 	worker.Listen(ctx, reporter)
 
@@ -244,6 +324,14 @@ func TestWorkerWait(t *testing.T) {
 			},
 			Action: api.AssignmentChange_AssignmentActionUpdate,
 		},
+		{
+			Assignment: &api.Assignment{
+				Item: &api.Assignment_Volume{
+					Volume: &api.VolumeAssignment{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+				},
+			},
+			Action: api.AssignmentChange_AssignmentActionUpdate,
+		},
 	}
 
 	expectedTasks := []*api.Task{
@@ -264,6 +352,10 @@ func TestWorkerWait(t *testing.T) {
 		{ID: "task-2"},
 	}
 
+	expectedVolumes := []*api.VolumeAssignment{
+		{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+	}
+
 	var (
 		tasks    []*api.Task
 		assigned []*api.Task
@@ -292,6 +384,11 @@ func TestWorkerWait(t *testing.T) {
 		assert.NoError(t, err)
 		assert.NotNil(t, config)
 	}
+	for _, volume := range expectedVolumes {
+		_, err := executor.Volumes().Get(volume.VolumeID)
+		assert.Error(t, err)
+		assert.True(t, errors.Is(err, exec.ErrDependencyNotReady))
+	}
 
 	err := worker.Assign(ctx, nil)
 	assert.Nil(t, err)
@@ -317,16 +414,35 @@ func TestWorkerUpdate(t *testing.T) {
 	defer cleanup()
 
 	ctx := context.Background()
-	executor := &mockExecutor{dependencies: NewDependencyManager()}
+
+	pg := &testutils.FakePluginGetter{
+		Plugins: map[string]*testutils.FakePlugin{
+			"plugin-1": {
+				PluginName: "plugin-1",
+				PluginAddr: &net.UnixAddr{},
+			},
+			"plugin-2": {
+				PluginName: "plugin-2",
+				PluginAddr: &net.UnixAddr{},
+			},
+		},
+	}
+
+	executor := &mockExecutor{dependencies: NewDependencyManager(pg)}
 	worker := newWorker(db, executor, &testPublisherProvider{})
-	reporter := statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
-		log.G(ctx).WithFields(logrus.Fields{"task.id": taskID, "status": status}).Info("status update received")
-		return nil
-	})
+	reporter := newFakeReporter(
+		statusReporterFunc(func(ctx context.Context, taskID string, status *api.TaskStatus) error {
+			log.G(ctx).WithFields(log.Fields{"task.id": taskID, "status": status}).Info("status update received")
+			return nil
+		}),
+		volumeReporterFunc(func(ctx context.Context, volumeID string) error {
+			return nil
+		}),
+	)
 
 	worker.Listen(ctx, reporter)
 
-	// create existing task/secret/config
+	// create existing task/secret/config/volume
 	assert.NoError(t, worker.Assign(ctx, []*api.AssignmentChange{
 		{
 			Assignment: &api.Assignment{
@@ -352,6 +468,14 @@ func TestWorkerUpdate(t *testing.T) {
 			},
 			Action: api.AssignmentChange_AssignmentActionUpdate,
 		},
+		{
+			Assignment: &api.Assignment{
+				Item: &api.Assignment_Volume{
+					Volume: &api.VolumeAssignment{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+				},
+			},
+			Action: api.AssignmentChange_AssignmentActionUpdate,
+		},
 	}))
 
 	for _, testcase := range []struct {
@@ -360,6 +484,7 @@ func TestWorkerUpdate(t *testing.T) {
 		expectedSecrets  []*api.Secret
 		expectedConfigs  []*api.Config
 		expectedAssigned []*api.Task
+		expectedVolumes  []*api.VolumeAssignment
 	}{
 		{ // handle nil changeSet case.
 			expectedTasks: []*api.Task{
@@ -374,6 +499,9 @@ func TestWorkerUpdate(t *testing.T) {
 			expectedAssigned: []*api.Task{
 				{ID: "task-1"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+			},
 		},
 		{
 			// no changes
@@ -399,6 +527,9 @@ func TestWorkerUpdate(t *testing.T) {
 			expectedAssigned: []*api.Task{
 				{ID: "task-1"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+			},
 		},
 		{
 			// adding a secret and task
@@ -427,6 +558,14 @@ func TestWorkerUpdate(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionUpdate,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionUpdate,
+				},
 			},
 			expectedTasks: []*api.Task{
 				{ID: "task-1"},
@@ -444,6 +583,10 @@ func TestWorkerUpdate(t *testing.T) {
 				{ID: "task-1"},
 				{ID: "task-2"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+				{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+			},
 		},
 		{
 			// remove assigned task and secret, updating existing secret
@@ -488,6 +631,22 @@ func TestWorkerUpdate(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionUpdate,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionRemove,
+				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionUpdate,
+				},
 			},
 			expectedTasks: []*api.Task{
 				{ID: "task-2"},
@@ -501,6 +660,9 @@ func TestWorkerUpdate(t *testing.T) {
 			expectedAssigned: []*api.Task{
 				{ID: "task-2"},
 			},
+			expectedVolumes: []*api.VolumeAssignment{
+				{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+			},
 		},
 		{
 			// removing nonexistent items doesn't fail
@@ -553,6 +715,22 @@ func TestWorkerUpdate(t *testing.T) {
 					},
 					Action: api.AssignmentChange_AssignmentActionRemove,
 				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID1", VolumeID: "volume-1", Driver: &api.Driver{Name: "plugin-1"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionRemove,
+				},
+				{
+					Assignment: &api.Assignment{
+						Item: &api.Assignment_Volume{
+							Volume: &api.VolumeAssignment{ID: "volumeID2", VolumeID: "volume-2", Driver: &api.Driver{Name: "plugin-2"}},
+						},
+					},
+					Action: api.AssignmentChange_AssignmentActionRemove,
+				},
 			},
 		},
 	} {
@@ -584,6 +762,12 @@ func TestWorkerUpdate(t *testing.T) {
 			assert.NoError(t, err)
 			assert.NotNil(t, config)
 		}
+		for _, volume := range testcase.expectedVolumes {
+			_, err := executor.Volumes().Get(volume.VolumeID)
+			// volumes should not be ready yet, so we expect an error.
+			assert.Error(t, err)
+			assert.True(t, errors.Is(err, exec.ErrDependencyNotReady), "error: %v", err)
+		}
 	}
 }
 
@@ -617,3 +801,7 @@ func (m *mockExecutor) Secrets() exec.SecretsManager {
 func (m *mockExecutor) Configs() exec.ConfigsManager {
 	return m.dependencies.Configs()
 }
+
+func (m *mockExecutor) Volumes() exec.VolumesManager {
+	return m.dependencies.Volumes()
+}
