@@ -11,7 +11,6 @@ import (
 	"encoding/hex"
 	"encoding/pem"
 	"fmt"
-	"io/ioutil"
 	"net"
 	"os"
 	"sync"
@@ -26,15 +25,15 @@ import (
 	"github.com/cloudflare/cfssl/helpers"
 	"github.com/cloudflare/cfssl/initca"
 	"github.com/docker/go-events"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/connectionbroker"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager/state"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/remotes"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/connectionbroker"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/manager/state"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/remotes"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/opencontainers/go-digest"
 	"github.com/phayes/permbits"
 	"github.com/stretchr/testify/assert"
@@ -79,10 +78,7 @@ func TestMain(m *testing.M) {
 }
 
 func TestCreateRootCASaveRootCA(t *testing.T) {
-	tempBaseDir, err := ioutil.TempDir("", "swarm-ca-test-")
-	assert.NoError(t, err)
-	defer os.RemoveAll(tempBaseDir)
-
+	tempBaseDir := t.TempDir()
 	paths := ca.NewConfigPaths(tempBaseDir)
 
 	rootCA, err := ca.CreateRootCA("rootCN")
@@ -100,7 +96,7 @@ func TestCreateRootCASaveRootCA(t *testing.T) {
 	assert.True(t, os.IsNotExist(err))
 
 	// ensure that the cert that was written is already normalized
-	written, err := ioutil.ReadFile(paths.RootCA.Cert)
+	written, err := os.ReadFile(paths.RootCA.Cert)
 	assert.NoError(t, err)
 	assert.Equal(t, written, ca.NormalizePEMs(written))
 }
@@ -118,14 +114,11 @@ func TestCreateRootCAExpiry(t *testing.T) {
 }
 
 func TestGetLocalRootCA(t *testing.T) {
-	tempBaseDir, err := ioutil.TempDir("", "swarm-ca-test-")
-	assert.NoError(t, err)
-	defer os.RemoveAll(tempBaseDir)
-
+	tempBaseDir := t.TempDir()
 	paths := ca.NewConfigPaths(tempBaseDir)
 
 	// First, try to load the local Root CA with the certificate missing.
-	_, err = ca.GetLocalRootCA(paths.RootCA)
+	_, err := ca.GetLocalRootCA(paths.RootCA)
 	assert.Equal(t, ca.ErrNoLocalRootCA, err)
 
 	// Create the local Root CA to ensure that we can reload it correctly.
@@ -144,7 +137,7 @@ func TestGetLocalRootCA(t *testing.T) {
 	assert.Equal(t, err, ca.ErrNoValidSigner)
 
 	// write private key and assert we can load it and sign
-	assert.NoError(t, ioutil.WriteFile(paths.RootCA.Key, s.Key, os.FileMode(0600)))
+	assert.NoError(t, os.WriteFile(paths.RootCA.Key, s.Key, os.FileMode(0o600)))
 	rootCA3, err := ca.GetLocalRootCA(paths.RootCA)
 	assert.NoError(t, err)
 	assert.Equal(t, rootCA.Certs, rootCA3.Certs)
@@ -160,33 +153,27 @@ func TestGetLocalRootCA(t *testing.T) {
 		Type:  "EC PRIVATE KEY",
 		Bytes: privKeyBytes,
 	})
-	assert.NoError(t, ioutil.WriteFile(paths.RootCA.Key, privKeyPem, os.FileMode(0600)))
+	assert.NoError(t, os.WriteFile(paths.RootCA.Key, privKeyPem, os.FileMode(0o600)))
 
 	_, err = ca.GetLocalRootCA(paths.RootCA)
 	assert.EqualError(t, err, "certificate key mismatch")
 }
 
 func TestGetLocalRootCAInvalidCert(t *testing.T) {
-	tempBaseDir, err := ioutil.TempDir("", "swarm-ca-test-")
-	assert.NoError(t, err)
-	defer os.RemoveAll(tempBaseDir)
-
+	tempBaseDir := t.TempDir()
 	paths := ca.NewConfigPaths(tempBaseDir)
 
 	// Write some garbage to the CA cert
-	require.NoError(t, ioutil.WriteFile(paths.RootCA.Cert, []byte(`-----BEGIN CERTIFICATE-----\n
+	require.NoError(t, os.WriteFile(paths.RootCA.Cert, []byte(`-----BEGIN CERTIFICATE-----\n
 some random garbage\n
------END CERTIFICATE-----`), 0644))
+-----END CERTIFICATE-----`), 0o644))
 
-	_, err = ca.GetLocalRootCA(paths.RootCA)
+	_, err := ca.GetLocalRootCA(paths.RootCA)
 	require.Error(t, err)
 }
 
 func TestGetLocalRootCAInvalidKey(t *testing.T) {
-	tempBaseDir, err := ioutil.TempDir("", "swarm-ca-test-")
-	assert.NoError(t, err)
-	defer os.RemoveAll(tempBaseDir)
-
+	tempBaseDir := t.TempDir()
 	paths := ca.NewConfigPaths(tempBaseDir)
 	// Create the local Root CA to ensure that we can reload it correctly.
 	rootCA, err := ca.CreateRootCA("rootCN")
@@ -194,9 +181,9 @@ func TestGetLocalRootCAInvalidKey(t *testing.T) {
 	require.NoError(t, ca.SaveRootCA(rootCA, paths.RootCA))
 
 	// Write some garbage to the root key - this will cause the loading to fail
-	require.NoError(t, ioutil.WriteFile(paths.RootCA.Key, []byte(`-----BEGIN PRIVATE KEY-----\n
+	require.NoError(t, os.WriteFile(paths.RootCA.Key, []byte(`-----BEGIN PRIVATE KEY-----\n
 some random garbage\n
------END PRIVATE KEY-----`), 0600))
+-----END PRIVATE KEY-----`), 0o600))
 
 	_, err = ca.GetLocalRootCA(paths.RootCA)
 	require.Error(t, err)
@@ -230,7 +217,7 @@ func TestParseValidateAndSignMaliciousCSR(t *testing.T) {
 		},
 		CN:         "maliciousCN",
 		Hosts:      []string{"docker.com"},
-		KeyRequest: &cfcsr.BasicKeyRequest{A: "ecdsa", S: 256},
+		KeyRequest: &cfcsr.KeyRequest{A: "ecdsa", S: 256},
 	}
 
 	csr, _, err := cfcsr.ParseRequest(req)
@@ -261,9 +248,7 @@ func TestGetRemoteCA(t *testing.T) {
 
 	// update the test CA to include a multi-certificate bundle as the root - the digest
 	// we use to verify with must be the digest of the whole bundle
-	tmpDir, err := ioutil.TempDir("", "GetRemoteCA")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
+	tmpDir := t.TempDir()
 	paths := ca.NewConfigPaths(tmpDir)
 	otherRootCA, err := ca.CreateRootCA("other")
 	require.NoError(t, err)
@@ -338,7 +323,7 @@ func testRequestAndSaveNewCertificates(t *testing.T, tc *cautils.TestCA) (*ca.Is
 	require.False(t, perms.GroupWrite())
 	require.False(t, perms.OtherWrite())
 
-	certs, err := ioutil.ReadFile(tc.Paths.Node.Cert)
+	certs, err := os.ReadFile(tc.Paths.Node.Cert)
 	require.NoError(t, err)
 	require.Equal(t, certs, ca.NormalizePEMs(certs))
 
@@ -374,10 +359,7 @@ func TestRequestAndSaveNewCertificatesWithIntermediates(t *testing.T) {
 			CrossSignedCACert: concat([]byte("   "), cautils.ECDSACertChain[1]),
 		},
 	}
-	tempdir, err := ioutil.TempDir("", "test-request-and-save-new-certificates")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	tc := cautils.NewTestCAFromAPIRootCA(t, tempdir, apiRootCA, nil)
 	defer tc.Stop()
 	issuerInfo, parsedCerts := testRequestAndSaveNewCertificates(t, tc)
@@ -453,13 +435,12 @@ func TestRequestAndSaveNewCertificatesWithKEKUpdate(t *testing.T) {
 
 // returns the issuer of the issued certificate and the parsed certs of the issued certificate
 func testIssueAndSaveNewCertificates(t *testing.T, rca *ca.RootCA) {
-	tempdir, err := ioutil.TempDir("", "test-issue-and-save-new-certificates")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(paths.Node, nil, nil)
 
 	var issuer *x509.Certificate
+	var err error
 	if len(rca.Intermediates) > 0 {
 		issuer, err = helpers.ParseCertificatePEM(rca.Intermediates)
 		require.NoError(t, err)
@@ -485,7 +466,7 @@ func testIssueAndSaveNewCertificates(t *testing.T, rca *ca.RootCA) {
 		require.False(t, perms.GroupWrite())
 		require.False(t, perms.OtherWrite())
 
-		certBytes, err := ioutil.ReadFile(paths.Node.Cert)
+		certBytes, err := os.ReadFile(paths.Node.Cert)
 		require.NoError(t, err)
 		parsed := checkLeafCert(t, certBytes, issuer.Subject.CommonName, "CN", role, "org", additionalNames...)
 		if len(rca.Intermediates) > 0 {
@@ -598,10 +579,11 @@ func newNonSigningCAServer(t *testing.T, tc *cautils.TestCA) *nonSigningCAServer
 
 	api.RegisterNodeCAServer(grpcServer, n)
 	go grpcServer.Serve(l)
+	t.Cleanup(n.server.Stop)
 	return n
 }
 
-func (n *nonSigningCAServer) stop(t *testing.T) {
+func (n *nonSigningCAServer) stop() {
 	n.server.Stop()
 }
 
@@ -688,7 +670,6 @@ func TestGetRemoteSignedCertificateWithPending(t *testing.T) {
 	defer cancel()
 
 	fakeCAServer := newNonSigningCAServer(t, tc)
-	defer fakeCAServer.stop(t)
 
 	completed := make(chan error)
 	defer close(completed)
@@ -831,8 +812,6 @@ func TestGetRemoteSignedCertificateConnectionErrors(t *testing.T) {
 
 	// create 2 CA servers referencing the same memory store, so we can have multiple connections
 	fakeSigningServers := []*nonSigningCAServer{newNonSigningCAServer(t, tc), newNonSigningCAServer(t, tc)}
-	defer fakeSigningServers[0].stop(t)
-	defer fakeSigningServers[1].stop(t)
 	multiBroker := connectionbroker.New(&fakeRemotes{
 		peers: []api.Peer{
 			{Addr: fakeSigningServers[0].addr},
@@ -865,7 +844,7 @@ func TestGetRemoteSignedCertificateConnectionErrors(t *testing.T) {
 
 	// stop 1 server, because it will have been the remote GetRemoteSignedCertificate first connected to, and ensure
 	// that GetRemoteSignedCertificate is still going
-	fakeSigningServers[0].stop(t)
+	fakeSigningServers[0].stop()
 	select {
 	case <-completed:
 		require.FailNow(t, "GetRemoteSignedCertificate should still be going after 2.5 seconds")
@@ -882,7 +861,7 @@ func TestGetRemoteSignedCertificateConnectionErrors(t *testing.T) {
 	}, time.Second*2))
 
 	// kill the last server - this should cause GetRemoteSignedCertificate to fail because there are no more peers
-	fakeSigningServers[1].stop(t)
+	fakeSigningServers[1].stop()
 	// wait for 5 seconds and ensure that GetRemoteSignedCertificate has returned with an error.
 	select {
 	case err = <-completed:
@@ -894,7 +873,6 @@ func TestGetRemoteSignedCertificateConnectionErrors(t *testing.T) {
 	// calling GetRemoteSignedCertificate with a connection that doesn't work with IssueNodeCertificate will fail
 	// immediately without retrying with a new connection
 	fakeSigningServers[1] = newNonSigningCAServer(t, tc)
-	defer fakeSigningServers[1].stop(t)
 	multiBroker = connectionbroker.New(&fakeRemotes{
 		peers: []api.Peer{
 			{Addr: fakeSigningServers[0].addr},
@@ -926,10 +904,7 @@ func TestNewRootCA(t *testing.T) {
 }
 
 func TestNewRootCABundle(t *testing.T) {
-	tempBaseDir, err := ioutil.TempDir("", "swarm-ca-test-")
-	assert.NoError(t, err)
-	defer os.RemoveAll(tempBaseDir)
-
+	tempBaseDir := t.TempDir()
 	paths := ca.NewConfigPaths(tempBaseDir)
 
 	// make one rootCA
@@ -944,7 +919,7 @@ func TestNewRootCABundle(t *testing.T) {
 
 	// Overwrite the bytes of the second Root CA with the bundle, creating a valid 2 cert bundle
 	bundle := append(firstRootCA.Certs, secondRootCA.Certs...)
-	err = ioutil.WriteFile(paths.RootCA.Cert, bundle, 0644)
+	err = os.WriteFile(paths.RootCA.Cert, bundle, 0o644)
 	assert.NoError(t, err)
 
 	newRootCA, err := ca.NewRootCA(bundle, firstRootCA.Certs, s.Key, ca.DefaultNodeCertExpiration, nil)
@@ -957,7 +932,7 @@ func TestNewRootCABundle(t *testing.T) {
 	_, _, err = newRootCA.IssueAndSaveNewCertificates(kw, "CN", "OU", "ORG")
 	assert.NoError(t, err)
 
-	certBytes, err := ioutil.ReadFile(paths.Node.Cert)
+	certBytes, err := os.ReadFile(paths.Node.Cert)
 	assert.NoError(t, err)
 	assert.Len(t, checkLeafCert(t, certBytes, "rootCN1", "CN", "OU", "ORG"), 1)
 }
@@ -1189,10 +1164,6 @@ func TestNewRootCAInvalidCertAndKeys(t *testing.T) {
 }
 
 func TestRootCAWithCrossSignedIntermediates(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "swarm-ca-test-")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
 	// re-generate the intermediate to be a self-signed root, and use that as the second root
 	parsedKey, err := helpers.ParsePrivateKeyPEM(cautils.ECDSACertChainKeys[1])
 	require.NoError(t, err)
@@ -1215,6 +1186,7 @@ func TestRootCAWithCrossSignedIntermediates(t *testing.T) {
 		ca.DefaultNodeCertExpiration, cautils.ECDSACertChain[1])
 	require.NoError(t, err)
 
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(paths.Node, nil, nil)
 	_, _, err = signWithIntermediate.IssueAndSaveNewCertificates(krw, "cn", "ou", "org")
@@ -1461,7 +1433,7 @@ func TestRootCACrossSignCACertificate(t *testing.T) {
 
 	rsaReq := cfcsr.CertificateRequest{
 		CN: "rootCNRSA",
-		KeyRequest: &cfcsr.BasicKeyRequest{
+		KeyRequest: &cfcsr.KeyRequest{
 			A: "rsa",
 			S: 2048,
 		},
@@ -1485,9 +1457,7 @@ func TestRootCACrossSignCACertificate(t *testing.T) {
 		},
 	}
 
-	tempdir, err := ioutil.TempDir("", "cross-sign-cert")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(paths.Node, nil, nil)
 
