@@ -2,13 +2,13 @@ package ca_test
 
 import (
 	"bytes"
+	"context"
 	"crypto/tls"
 	"crypto/x509"
-	"fmt"
-	"io/ioutil"
 	"net"
 	"os"
 	"path/filepath"
+	"strconv"
 	"strings"
 	"testing"
 	"time"
@@ -16,19 +16,16 @@ import (
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/credentials"
 
-	"golang.org/x/net/context"
-
 	cfconfig "github.com/cloudflare/cfssl/config"
 	"github.com/cloudflare/cfssl/helpers"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/log"
-	"github.com/docker/swarmkit/manager/state"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager/state"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/pkg/errors"
-	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -58,7 +55,7 @@ func testDownloadRootCASuccess(t *testing.T, fips bool) {
 	require.True(t, strings.HasPrefix(token, prefix))
 
 	// Remove the CA cert
-	os.RemoveAll(tc.Paths.RootCA.Cert)
+	assert.NoError(t, os.RemoveAll(tc.Paths.RootCA.Cert))
 
 	rootCA, err := ca.DownloadRootCA(tc.Context, tc.Paths.RootCA, token, tc.ConnBroker)
 	require.NoError(t, err)
@@ -69,7 +66,7 @@ func testDownloadRootCASuccess(t *testing.T, fips bool) {
 	require.Equal(t, tc.RootCA.Certs, rootCA.Certs)
 
 	// Remove the CA cert
-	os.RemoveAll(tc.Paths.RootCA.Cert)
+	assert.NoError(t, os.RemoveAll(tc.Paths.RootCA.Cert))
 
 	// downloading without a join token also succeeds
 	rootCA, err = ca.DownloadRootCA(tc.Context, tc.Paths.RootCA, "", tc.ConnBroker)
@@ -86,7 +83,7 @@ func TestDownloadRootCAWrongCAHash(t *testing.T) {
 	defer tc.Stop()
 
 	// Remove the CA cert
-	os.RemoveAll(tc.Paths.RootCA.Cert)
+	assert.NoError(t, os.RemoveAll(tc.Paths.RootCA.Cert))
 
 	// invalid token
 	for _, invalid := range []string{
@@ -124,7 +121,7 @@ func TestCreateSecurityConfigEmptyDir(t *testing.T) {
 		"",
 		"my_org",
 	} {
-		os.RemoveAll(tc.TempDir)
+		assert.NoError(t, os.RemoveAll(tc.TempDir))
 		krw := ca.NewKeyReadWriter(tc.Paths.Node, nil, nil)
 		nodeConfig, cancel, err := tc.RootCA.CreateSecurityConfig(tc.Context, krw,
 			ca.CertificateRequestConfig{
@@ -133,7 +130,7 @@ func TestCreateSecurityConfigEmptyDir(t *testing.T) {
 				Organization: org,
 			})
 		assert.NoError(t, err)
-		cancel()
+		assert.NoError(t, cancel())
 		assert.NotNil(t, nodeConfig)
 		assert.NotNil(t, nodeConfig.ClientTLSCreds)
 		assert.NotNil(t, nodeConfig.ServerTLSCreds)
@@ -167,7 +164,7 @@ func TestCreateSecurityConfigNoCerts(t *testing.T) {
 				ConnBroker: tc.ConnBroker,
 			})
 		assert.NoError(t, err)
-		cancel()
+		assert.NoError(t, cancel())
 		assert.NotNil(t, nodeConfig)
 		assert.NotNil(t, nodeConfig.ClientTLSCreds)
 		assert.NotNil(t, nodeConfig.ServerTLSCreds)
@@ -184,12 +181,12 @@ func TestCreateSecurityConfigNoCerts(t *testing.T) {
 
 	// Remove only the node certificates form the directory, and attest that we get
 	// new certificates that are locally signed
-	os.RemoveAll(tc.Paths.Node.Cert)
+	assert.NoError(t, os.RemoveAll(tc.Paths.Node.Cert))
 	validateNodeConfig(&tc.RootCA)
 
 	// Remove only the node certificates form the directory, get a new rootCA, and attest that we get
 	// new certificates that are issued by the remote CA
-	os.RemoveAll(tc.Paths.Node.Cert)
+	assert.NoError(t, os.RemoveAll(tc.Paths.Node.Cert))
 	rootCA, err := ca.GetLocalRootCA(tc.Paths.RootCA)
 	assert.NoError(t, err)
 	validateNodeConfig(&rootCA)
@@ -213,7 +210,7 @@ func testGRPCConnection(t *testing.T, secConfig *ca.SecurityConfig) {
 	}
 	conn, err := grpc.Dial(l.Addr().String(), dialOpts...)
 	require.NoError(t, err)
-	conn.Close()
+	assert.NoError(t, conn.Close())
 }
 
 func TestLoadSecurityConfigExpiredCert(t *testing.T) {
@@ -235,7 +232,7 @@ func TestLoadSecurityConfigExpiredCert(t *testing.T) {
 
 	// A cert that is not yet valid is not valid even if expiry is allowed
 	invalidCert := cautils.ReDateCert(t, certBytes, tc.RootCA.Certs, s.Key, now.Add(time.Hour), now.Add(time.Hour*2))
-	require.NoError(t, ioutil.WriteFile(tc.Paths.Node.Cert, invalidCert, 0700))
+	require.NoError(t, os.WriteFile(tc.Paths.Node.Cert, invalidCert, 0o700))
 
 	_, _, err = ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
 	require.Error(t, err)
@@ -247,7 +244,7 @@ func TestLoadSecurityConfigExpiredCert(t *testing.T) {
 
 	// a cert that is expired is not valid if expiry is not allowed
 	invalidCert = cautils.ReDateCert(t, certBytes, tc.RootCA.Certs, s.Key, now.Add(-2*time.Minute), now.Add(-1*time.Minute))
-	require.NoError(t, ioutil.WriteFile(tc.Paths.Node.Cert, invalidCert, 0700))
+	require.NoError(t, os.WriteFile(tc.Paths.Node.Cert, invalidCert, 0o700))
 
 	_, _, err = ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
 	require.Error(t, err)
@@ -256,7 +253,7 @@ func TestLoadSecurityConfigExpiredCert(t *testing.T) {
 	// but it is valid if expiry is allowed
 	_, cancel, err := ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, true)
 	require.NoError(t, err)
-	cancel()
+	assert.NoError(t, cancel())
 }
 
 func TestLoadSecurityConfigInvalidCert(t *testing.T) {
@@ -267,13 +264,14 @@ func TestLoadSecurityConfigInvalidCert(t *testing.T) {
 	defer tc.Stop()
 
 	// Write some garbage to the cert
-	ioutil.WriteFile(tc.Paths.Node.Cert, []byte(`-----BEGIN CERTIFICATE-----\n
+	err := os.WriteFile(tc.Paths.Node.Cert, []byte(`-----BEGIN CERTIFICATE-----\n
 some random garbage\n
------END CERTIFICATE-----`), 0644)
+-----END CERTIFICATE-----`), 0o644)
+	assert.NoError(t, err)
 
 	krw := ca.NewKeyReadWriter(tc.Paths.Node, nil, nil)
 
-	_, _, err := ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
+	_, _, err = ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
 	assert.Error(t, err)
 }
 
@@ -285,13 +283,14 @@ func TestLoadSecurityConfigInvalidKey(t *testing.T) {
 	defer tc.Stop()
 
 	// Write some garbage to the Key
-	ioutil.WriteFile(tc.Paths.Node.Key, []byte(`-----BEGIN PRIVATE KEY-----\n
+	err := os.WriteFile(tc.Paths.Node.Key, []byte(`-----BEGIN PRIVATE KEY-----\n
 some random garbage\n
------END PRIVATE KEY-----`), 0644)
+-----END PRIVATE KEY-----`), 0o644)
+	assert.NoError(t, err)
 
 	krw := ca.NewKeyReadWriter(tc.Paths.Node, nil, nil)
 
-	_, _, err := ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
+	_, _, err = ca.LoadSecurityConfig(tc.Context, tc.RootCA, krw, false)
 	assert.Error(t, err)
 }
 
@@ -315,16 +314,14 @@ func TestLoadSecurityConfigIntermediates(t *testing.T) {
 	if cautils.External {
 		return // this doesn't require any servers at all
 	}
-	tempdir, err := ioutil.TempDir("", "test-load-config-with-intermediates")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(paths.Node, nil, nil)
 
 	rootCA, err := ca.NewRootCA(cautils.ECDSACertChain[2], nil, nil, ca.DefaultNodeCertExpiration, nil)
 	require.NoError(t, err)
 
-	ctx := log.WithLogger(context.Background(), log.L.WithFields(logrus.Fields{
+	ctx := log.WithLogger(context.Background(), log.L.WithFields(log.Fields{
 		"testname":          t.Name(),
 		"testHasExternalCA": false,
 	}))
@@ -355,16 +352,14 @@ func TestLoadSecurityConfigKeyFormat(t *testing.T) {
 	if cautils.External {
 		return // this doesn't require any servers at all
 	}
-	tempdir, err := ioutil.TempDir("", "test-load-config")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(paths.Node, nil, nil)
 
 	rootCA, err := ca.NewRootCA(cautils.ECDSACertChain[1], nil, nil, ca.DefaultNodeCertExpiration, nil)
 	require.NoError(t, err)
 
-	ctx := log.WithLogger(context.Background(), log.L.WithFields(logrus.Fields{
+	ctx := log.WithLogger(context.Background(), log.L.WithFields(log.Fields{
 		"testname":          t.Name(),
 		"testHasExternalCA": false,
 	}))
@@ -441,15 +436,13 @@ func TestSecurityConfigUpdateRootCA(t *testing.T) {
 	rootCA, err := ca.NewRootCA(cert, cert, key, ca.DefaultNodeCertExpiration, nil)
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "test-security-config-update")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
 	configPaths := ca.NewConfigPaths(tempdir)
 
 	secConfig, cancel, err := rootCA.CreateSecurityConfig(tc.Context,
 		ca.NewKeyReadWriter(configPaths.Node, nil, nil), ca.CertificateRequestConfig{})
 	require.NoError(t, err)
-	cancel()
+	assert.NoError(t, cancel())
 	// update the server TLS to require certificates, otherwise this will all pass
 	// even if the root pools aren't updated
 	secConfig.ServerTLSCreds.Config().ClientAuth = tls.RequireAndVerifyClientCert
@@ -504,7 +497,7 @@ func TestSecurityConfigUpdateRootCA(t *testing.T) {
 		grpc.WithTransportCredentials(tcConfig.ClientTLSCreds),
 	)
 	require.NoError(t, err)
-	conn.Close()
+	assert.NoError(t, conn.Close())
 
 	conn, err = grpc.Dial(
 		tc.Addr,
@@ -513,7 +506,7 @@ func TestSecurityConfigUpdateRootCA(t *testing.T) {
 		grpc.WithTransportCredentials(secConfig.ClientTLSCreds),
 	)
 	require.NoError(t, err)
-	conn.Close()
+	assert.NoError(t, conn.Close())
 
 	// make sure any generated certs after updating contain the intermediate
 	krw := ca.NewKeyReadWriter(configPaths.Node, nil, nil)
@@ -536,8 +529,7 @@ func TestSecurityConfigUpdateRootCAUpdateConsistentWithTLSCertificates(t *testin
 	if cautils.External {
 		return // we don't care about external CAs at all
 	}
-	tempdir, err := ioutil.TempDir("", "")
-	require.NoError(t, err)
+	tempdir := t.TempDir()
 	krw := ca.NewKeyReadWriter(ca.NewConfigPaths(tempdir).Node, nil, nil)
 
 	rootCA, err := ca.CreateRootCA("rootcn")
@@ -562,7 +554,7 @@ func TestSecurityConfigUpdateRootCAUpdateConsistentWithTLSCertificates(t *testin
 
 	secConfig, cancel, err := ca.NewSecurityConfig(&rootCA, krw, tlsKeyPair, issuerInfo)
 	require.NoError(t, err)
-	cancel()
+	assert.NoError(t, cancel())
 
 	// can't update the root CA to one that doesn't match the tls certs
 	require.Error(t, secConfig.UpdateRootCA(&otherRootCA))
@@ -629,19 +621,16 @@ func TestSecurityConfigWatch(t *testing.T) {
 // root certificate.  If it validates against the current TLS credentials, it will be used to download
 // new ones, (only if the new certificate indicates that it's a worker, though).
 func TestRenewTLSConfigUpdatesRootOnUnknownAuthError(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-renew-tls-config-now-downloads-root")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
 	// make 3 CAs
 	var (
 		certs        = make([][]byte, 3)
 		keys         = make([][]byte, 3)
 		crossSigneds = make([][]byte, 3)
 		cas          = make([]ca.RootCA, 3)
+		err          error
 	)
 	for i := 0; i < 3; i++ {
-		certs[i], keys[i], err = cautils.CreateRootCertAndKey(fmt.Sprintf("CA%d", i))
+		certs[i], keys[i], err = cautils.CreateRootCertAndKey("CA" + strconv.Itoa(i))
 		require.NoError(t, err)
 		switch i {
 		case 0:
@@ -658,6 +647,7 @@ func TestRenewTLSConfigUpdatesRootOnUnknownAuthError(t *testing.T) {
 
 	// the CA server is going to start off with a cert issued by the second CA, cross-signed by the first CA, and then
 	// rotate to one issued by the third CA, cross-signed by the second.
+	tempdir := t.TempDir()
 	tc := cautils.NewTestCAFromAPIRootCA(t, tempdir, api.RootCA{
 		CACert: certs[0],
 		CAKey:  keys[0],
@@ -721,56 +711,56 @@ func TestRenewTLSConfigUpdatesRootOnUnknownAuthError(t *testing.T) {
 		// requests from certs different than the cluster root CA, add another test case to make sure that the downloaded
 		// root has to validate against both the old TLS creds and new TLS creds
 	} {
-		nodeID := fmt.Sprintf("node%d", i)
-		tlsKeyPair, issuerInfo, err := testCase.issuingRootCA.IssueAndSaveNewCertificates(krw, nodeID, ca.ManagerRole, tc.Organization)
-		require.NoError(t, err)
-		// make sure the node is added to the memory store as a worker, so when we renew the cert the test CA will answer
-		require.NoError(t, tc.MemoryStore.Update(func(tx store.Tx) error {
-			return store.CreateNode(tx, &api.Node{
-				Role: testCase.role,
-				ID:   nodeID,
-				Spec: api.NodeSpec{
-					DesiredRole:  testCase.role,
-					Membership:   api.NodeMembershipAccepted,
-					Availability: api.NodeAvailabilityActive,
-				},
-			})
-		}))
-		secConfig, qClose, err := ca.NewSecurityConfig(testCase.initialRootCA, krw, tlsKeyPair, issuerInfo)
-		require.NoError(t, err)
-		defer qClose()
-
-		paths := ca.NewConfigPaths(filepath.Join(tempdir, nodeID))
-		err = ca.RenewTLSConfigNow(tc.Context, secConfig, tc.ConnBroker, paths.RootCA)
-
-		// TODO(cyli): remove this role check once the codepaths for worker and manager are the same
-		if testCase.expectedRoot != nil {
-			// only rotate if we are a worker, and if the new cert validates against the old TLS creds
+		testCase := testCase
+		nodeID := "node" + strconv.Itoa(i)
+		t.Run(nodeID, func(t *testing.T) {
+			tlsKeyPair, issuerInfo, err := testCase.issuingRootCA.IssueAndSaveNewCertificates(krw, nodeID, ca.ManagerRole, tc.Organization)
 			require.NoError(t, err)
-			downloadedRoot, err := ioutil.ReadFile(paths.RootCA.Cert)
+			// make sure the node is added to the memory store as a worker, so when we renew the cert the test CA will answer
+			require.NoError(t, tc.MemoryStore.Update(func(tx store.Tx) error {
+				return store.CreateNode(tx, &api.Node{
+					Role: testCase.role,
+					ID:   nodeID,
+					Spec: api.NodeSpec{
+						DesiredRole:  testCase.role,
+						Membership:   api.NodeMembershipAccepted,
+						Availability: api.NodeAvailabilityActive,
+					},
+				})
+			}))
+			secConfig, qClose, err := ca.NewSecurityConfig(testCase.initialRootCA, krw, tlsKeyPair, issuerInfo)
 			require.NoError(t, err)
-			require.Equal(t, testCase.expectedRoot, downloadedRoot)
-		} else {
-			require.Error(t, err)
-			require.IsType(t, x509.UnknownAuthorityError{}, err)
-			_, err = ioutil.ReadFile(paths.RootCA.Cert) // we didn't download a file
-			require.Error(t, err)
-		}
+			defer qClose()
+
+			paths := ca.NewConfigPaths(filepath.Join(tempdir, nodeID))
+			err = ca.RenewTLSConfigNow(tc.Context, secConfig, tc.ConnBroker, paths.RootCA)
+
+			// TODO(cyli): remove this role check once the codepaths for worker and manager are the same
+			if testCase.expectedRoot != nil {
+				// only rotate if we are a worker, and if the new cert validates against the old TLS creds
+				require.NoError(t, err)
+				downloadedRoot, err := os.ReadFile(paths.RootCA.Cert)
+				require.NoError(t, err)
+				require.Equal(t, testCase.expectedRoot, downloadedRoot)
+			} else {
+				require.Error(t, err)
+				require.IsType(t, x509.UnknownAuthorityError{}, err)
+				_, err = os.ReadFile(paths.RootCA.Cert) // we didn't download a file
+				require.Error(t, err)
+			}
+		})
 	}
 }
 
 // If we get a not unknown authority error when trying to renew the TLS certificate, just return the
 // error and do not attempt to download the root certificate.
 func TestRenewTLSConfigUpdatesRootNonUnknownAuthError(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-renew-tls-config-now-downloads-root")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
 	cert, key, err := cautils.CreateRootCertAndKey("rootCA")
 	require.NoError(t, err)
 	rootCA, err := ca.NewRootCA(cert, cert, key, ca.DefaultNodeCertExpiration, nil)
 	require.NoError(t, err)
 
+	tempdir := t.TempDir()
 	tc := cautils.NewTestCAFromAPIRootCA(t, tempdir, api.RootCA{
 		CACert: cert,
 		CAKey:  key,
@@ -778,7 +768,6 @@ func TestRenewTLSConfigUpdatesRootNonUnknownAuthError(t *testing.T) {
 	defer tc.Stop()
 
 	fakeCAServer := newNonSigningCAServer(t, tc)
-	defer fakeCAServer.stop(t)
 
 	secConfig, err := tc.NewNodeConfig(ca.WorkerRole)
 	require.NoError(t, err)
@@ -788,24 +777,22 @@ func TestRenewTLSConfigUpdatesRootNonUnknownAuthError(t *testing.T) {
 	go func() {
 		updates, cancel := state.Watch(tc.MemoryStore.WatchQueue(), api.EventCreateNode{})
 		defer cancel()
-		select {
-		case event := <-updates: // we want to skip the first node, which is the test CA
-			n := event.(api.EventCreateNode).Node
-			if n.Certificate.Status.State == api.IssuanceStatePending {
-				signErr <- tc.MemoryStore.Update(func(tx store.Tx) error {
-					node := store.GetNode(tx, n.ID)
-					certChain, err := rootCA.ParseValidateAndSignCSR(node.Certificate.CSR, node.Certificate.CN, ca.WorkerRole, tc.Organization)
-					if err != nil {
-						return err
-					}
-					node.Certificate.Certificate = cautils.ReDateCert(t, certChain, cert, key, time.Now().Add(-5*time.Hour), time.Now().Add(-4*time.Hour))
-					node.Certificate.Status = api.IssuanceStatus{
-						State: api.IssuanceStateIssued,
-					}
-					return store.UpdateNode(tx, node)
-				})
-				return
-			}
+		event := <-updates // we want to skip the first node, which is the test CA
+		n := event.(api.EventCreateNode).Node
+		if n.Certificate.Status.State == api.IssuanceStatePending {
+			signErr <- tc.MemoryStore.Update(func(tx store.Tx) error {
+				node := store.GetNode(tx, n.ID)
+				certChain, err := rootCA.ParseValidateAndSignCSR(node.Certificate.CSR, node.Certificate.CN, ca.WorkerRole, tc.Organization)
+				if err != nil {
+					return err
+				}
+				node.Certificate.Certificate = cautils.ReDateCert(t, certChain, cert, key, time.Now().Add(-5*time.Hour), time.Now().Add(-4*time.Hour))
+				node.Certificate.Status = api.IssuanceStatus{
+					State: api.IssuanceStateIssued,
+				}
+				return store.UpdateNode(tx, node)
+			})
+			return
 		}
 	}()
 
@@ -825,11 +812,11 @@ func TestRenewTLSConfigUpdateRootCARace(t *testing.T) {
 	secConfig, err := tc.WriteNewNodeConfig(ca.ManagerRole)
 	require.NoError(t, err)
 
-	leafCert, err := ioutil.ReadFile(paths.Node.Cert)
+	leafCert, err := os.ReadFile(paths.Node.Cert)
 	require.NoError(t, err)
 
 	for i := 0; i < 5; i++ {
-		cert, _, err := cautils.CreateRootCertAndKey(fmt.Sprintf("root %d", i+2))
+		cert, _, err := cautils.CreateRootCertAndKey("root " + strconv.Itoa(i+2))
 		require.NoError(t, err)
 
 		ctx, cancel := context.WithCancel(tc.Context)
@@ -856,7 +843,7 @@ func TestRenewTLSConfigUpdateRootCARace(t *testing.T) {
 		<-done1
 		<-done2
 
-		newCert, err := ioutil.ReadFile(paths.Node.Cert)
+		newCert, err := os.ReadFile(paths.Node.Cert)
 		require.NoError(t, err)
 
 		require.NotEqual(t, newCert, leafCert)
