@@ -3,15 +3,15 @@ package ca_test
 import (
 	"encoding/pem"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"testing"
 
-	"github.com/docker/swarmkit/ca"
-	"github.com/docker/swarmkit/ca/keyutils"
-	"github.com/docker/swarmkit/ca/pkcs8"
-	"github.com/docker/swarmkit/ca/testutils"
+	"github.com/moby/swarmkit/v2/ca"
+	"github.com/moby/swarmkit/v2/ca/keyutils"
+	"github.com/moby/swarmkit/v2/ca/pkcs8"
+	"github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -23,10 +23,7 @@ func TestKeyReadWriter(t *testing.T) {
 
 	expectedKey := key
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	path := ca.NewConfigPaths(filepath.Join(tempdir, "subdir")) // to make sure subdirectories are created
 
 	checkCanReadWithKEK := func(kek []byte) *ca.KeyReadWriter {
@@ -59,7 +56,7 @@ func TestKeyReadWriter(t *testing.T) {
 	expectedKey = pem.EncodeToMemory(keyBlock)
 	// write a version, but that's not what we'd expect back once we read
 	keyBlock.Headers["kek-version"] = "8"
-	require.NoError(t, ioutil.WriteFile(path.Node.Key, pem.EncodeToMemory(keyBlock), 0600))
+	require.NoError(t, os.WriteFile(path.Node.Key, pem.EncodeToMemory(keyBlock), 0o600))
 
 	// if a kek is provided, we can still read unencrypted keys, and read
 	// the provided version
@@ -131,13 +128,10 @@ func TestKeyReadWriterWithPemHeaderManager(t *testing.T) {
 	keyBlock.Headers = map[string]string{"hello": "world"}
 	key = pem.EncodeToMemory(keyBlock)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	path := ca.NewConfigPaths(filepath.Join(tempdir, "subdir")) // to make sure subdirectories are created
 
-	// if if getting new headers fail, writing a key fails, and the key does not rotate
+	// if getting new headers fails, writing a key fails, and the key does not rotate
 	var count int
 	badKEKData := ca.KEKData{KEK: []byte("failed kek"), Version: 3}
 	k := ca.NewKeyReadWriter(path.Node, nil, testHeaders{newHeaders: func(k ca.KEKData) (map[string]string, error) {
@@ -151,7 +145,7 @@ func TestKeyReadWriterWithPemHeaderManager(t *testing.T) {
 	}})
 	// first write will fail
 	require.Error(t, k.Write(cert, key, &badKEKData))
-	// the stored kek data will be not be updated because the write failed
+	// the stored kek data will not be updated because the write failed.
 	_, kekData := k.GetCurrentState()
 	require.Equal(t, ca.KEKData{}, kekData)
 	// second write will succeed, using the original kek (nil)
@@ -207,10 +201,7 @@ func TestKeyReadWriterViewAndUpdateHeaders(t *testing.T) {
 	cert, key, err := testutils.CreateRootCertAndKey("cn")
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	path := ca.NewConfigPaths(filepath.Join(tempdir))
 
 	// write a key with headers to the key to make sure it gets passed when reading/writing headers
@@ -218,8 +209,8 @@ func TestKeyReadWriterViewAndUpdateHeaders(t *testing.T) {
 	require.NotNil(t, keyBlock)
 	keyBlock.Headers = map[string]string{"hello": "world"}
 	key = pem.EncodeToMemory(keyBlock)
-	require.NoError(t, ioutil.WriteFile(path.Node.Cert, cert, 0644))
-	require.NoError(t, ioutil.WriteFile(path.Node.Key, key, 0600))
+	require.NoError(t, os.WriteFile(path.Node.Cert, cert, 0o644))
+	require.NoError(t, os.WriteFile(path.Node.Key, key, 0o600))
 
 	// if the update headers callback function fails, updating headers fails
 	k := ca.NewKeyReadWriter(path.Node, nil, nil)
@@ -273,10 +264,7 @@ func TestKeyReadWriterViewAndRotateKEK(t *testing.T) {
 	cert, key, err := testutils.CreateRootCertAndKey("cn")
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	path := ca.NewConfigPaths(filepath.Join(tempdir))
 
 	// write a key with headers to the key to make sure it gets passed when reading/writing headers
@@ -286,7 +274,7 @@ func TestKeyReadWriterViewAndRotateKEK(t *testing.T) {
 	key = pem.EncodeToMemory(keyBlock)
 	require.NoError(t, ca.NewKeyReadWriter(path.Node, nil, nil).Write(cert, key, nil))
 
-	// if if getting new kek and headers fail, rotating a KEK fails, and the kek does not rotate
+	// if getting new kek and headers fails, rotating a KEK fails, and the kek does not rotate
 	k := ca.NewKeyReadWriter(path.Node, nil, nil)
 	require.Error(t, k.ViewAndRotateKEK(func(k ca.KEKData, h ca.PEMKeyHeaders) (ca.KEKData, ca.PEMKeyHeaders, error) {
 		require.Equal(t, ca.KEKData{}, k)
@@ -332,26 +320,24 @@ func TestTwoPhaseReadWrite(t *testing.T) {
 	cert2, key2, err := testutils.CreateRootCertAndKey("cn")
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
-	path := ca.NewConfigPaths(filepath.Join(tempdir))
+	tempdir := t.TempDir()
+	path := ca.NewConfigPaths(tempdir)
 	krw := ca.NewKeyReadWriter(path.Node, nil, nil)
 
 	// put a directory in the location where the cert goes, so we can't actually move
 	// the cert from the temporary location to the final location.
-	require.NoError(t, os.Mkdir(filepath.Join(path.Node.Cert), 0755))
+	require.NoError(t, os.Mkdir(path.Node.Cert, 0o755))
 	require.Error(t, krw.Write(cert2, key2, nil))
 
 	// the temp cert file should exist
 	tempCertPath := filepath.Join(filepath.Dir(path.Node.Cert), "."+filepath.Base(path.Node.Cert))
-	readCert, err := ioutil.ReadFile(tempCertPath)
+	readCert, err := os.ReadFile(tempCertPath)
 	require.NoError(t, err)
 	require.Equal(t, cert2, readCert)
 
 	// remove the directory, to simulate it failing to write the first time
-	os.RemoveAll(path.Node.Cert)
+	err = os.RemoveAll(path.Node.Cert)
+	assert.NoError(t, err)
 	readCert, readKey, err := krw.Read()
 	require.NoError(t, err)
 	require.Equal(t, cert2, readCert)
@@ -361,8 +347,8 @@ func TestTwoPhaseReadWrite(t *testing.T) {
 	require.True(t, os.IsNotExist(err))
 
 	// If the cert in the proper location doesn't match the key, the temp location is checked
-	require.NoError(t, ioutil.WriteFile(tempCertPath, cert2, 0644))
-	require.NoError(t, ioutil.WriteFile(path.Node.Cert, cert1, 0644))
+	require.NoError(t, os.WriteFile(tempCertPath, cert2, 0o644))
+	require.NoError(t, os.WriteFile(path.Node.Cert, cert1, 0o644))
 	readCert, readKey, err = krw.Read()
 	require.NoError(t, err)
 	require.Equal(t, cert2, readCert)
@@ -374,7 +360,7 @@ func TestTwoPhaseReadWrite(t *testing.T) {
 	// If the cert in the temp location also doesn't match, the failure matching the
 	// correctly-located cert is returned
 	require.NoError(t, os.Remove(path.Node.Cert))
-	require.NoError(t, ioutil.WriteFile(tempCertPath, cert1, 0644)) // mismatching cert
+	require.NoError(t, os.WriteFile(tempCertPath, cert1, 0o644)) // mismatching cert
 	_, _, err = krw.Read()
 	require.True(t, os.IsNotExist(err))
 	// the cert should have been removed
@@ -386,16 +372,13 @@ func TestKeyReadWriterMigrate(t *testing.T) {
 	cert, key, err := testutils.CreateRootCertAndKey("cn")
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
-	path := ca.NewConfigPaths(filepath.Join(tempdir))
+	tempdir := t.TempDir()
+	path := ca.NewConfigPaths(tempdir)
 
 	// if the key exists in an old location, migrate it from there.
 	tempKeyPath := filepath.Join(filepath.Dir(path.Node.Key), "."+filepath.Base(path.Node.Key))
-	require.NoError(t, ioutil.WriteFile(path.Node.Cert, cert, 0644))
-	require.NoError(t, ioutil.WriteFile(tempKeyPath, key, 0600))
+	require.NoError(t, os.WriteFile(path.Node.Cert, cert, 0o644))
+	require.NoError(t, os.WriteFile(tempKeyPath, key, 0o600))
 
 	krw := ca.NewKeyReadWriter(path.Node, nil, nil)
 	require.NoError(t, krw.Migrate())
@@ -405,10 +388,10 @@ func TestKeyReadWriterMigrate(t *testing.T) {
 	require.NoError(t, err)
 
 	// migrate does not affect any existing files
-	dirList, err := ioutil.ReadDir(filepath.Dir(path.Node.Key))
+	dirList, err := os.ReadDir(filepath.Dir(path.Node.Key))
 	require.NoError(t, err)
 	require.NoError(t, krw.Migrate())
-	dirList2, err := ioutil.ReadDir(filepath.Dir(path.Node.Key))
+	dirList2, err := os.ReadDir(filepath.Dir(path.Node.Key))
 	require.NoError(t, err)
 	require.Equal(t, dirList, dirList2)
 	_, _, err = krw.Read()
@@ -442,11 +425,8 @@ func testKeyReadWriterDowngradeKeyCase(t *testing.T, tc downgradeTestCase) error
 		key = pem.EncodeToMemory(block)
 	}
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriterDowngrade")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
-	path := ca.NewConfigPaths(filepath.Join(tempdir))
+	tempdir := t.TempDir()
+	path := ca.NewConfigPaths(tempdir)
 
 	block, _ := pem.Decode(key)
 	require.NotNil(t, block)
@@ -455,8 +435,8 @@ func testKeyReadWriterDowngradeKeyCase(t *testing.T, tc downgradeTestCase) error
 	block.Headers["kek-version"] = "5"
 
 	key = pem.EncodeToMemory(block)
-	require.NoError(t, ioutil.WriteFile(path.Node.Cert, cert, 0644))
-	require.NoError(t, ioutil.WriteFile(path.Node.Key, key, 0600))
+	require.NoError(t, os.WriteFile(path.Node.Cert, cert, 0o644))
+	require.NoError(t, os.WriteFile(path.Node.Key, key, 0o600))
 
 	// if the update headers callback function fails, updating headers fails
 	k := ca.NewKeyReadWriter(path.Node, kek, nil)
@@ -465,7 +445,7 @@ func testKeyReadWriterDowngradeKeyCase(t *testing.T, tc downgradeTestCase) error
 	}
 
 	// read the key directly from fs so we can check if key
-	key, err = ioutil.ReadFile(path.Node.Key)
+	key, err = os.ReadFile(path.Node.Key)
 	require.NoError(t, err)
 
 	keyBlock, _ := pem.Decode(key)
@@ -528,10 +508,7 @@ func TestKeyReadWriterReadNonFIPS(t *testing.T) {
 	key, err = pkcs8.ConvertToECPrivateKeyPEM(key)
 	require.NoError(t, err)
 
-	tempdir, err := ioutil.TempDir("", "KeyReadWriter")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	path := ca.NewConfigPaths(filepath.Join(tempdir, "subdir")) // to make sure subdirectories are created
 
 	k := ca.NewKeyReadWriter(path.Node, nil, nil)
