@@ -6,24 +6,21 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"fmt"
-	"io/ioutil"
-	"os"
 	"path/filepath"
 	"reflect"
 	"testing"
 	"time"
 
 	"github.com/cloudflare/cfssl/helpers"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/api/equality"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/log"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/api/equality"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/opencontainers/go-digest"
 	"github.com/pkg/errors"
-	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc/codes"
@@ -1171,16 +1168,13 @@ func TestRootRotationReconciliationRace(t *testing.T) {
 		t:  t,
 	}
 
-	tempDir, err := ioutil.TempDir("", "competing-ca-server")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempDir)
-
 	var (
 		otherServers   = make([]*ca.Server, 5)
 		serverContexts = make([]context.Context, 5)
 		paths          = make([]*ca.SecurityConfigPaths, 5)
 	)
 
+	tempDir := t.TempDir()
 	for i := 0; i < 5; i++ { // to make sure we get some collision
 		// start a competing CA server
 		paths[i] = ca.NewConfigPaths(filepath.Join(tempDir, fmt.Sprintf("%d", i)))
@@ -1192,7 +1186,7 @@ func TestRootRotationReconciliationRace(t *testing.T) {
 		// offset each server's reconciliation interval somewhat so that some will
 		// pre-empt others
 		otherServers[i].SetRootReconciliationInterval(time.Millisecond * time.Duration((i+1)*10))
-		serverContexts[i] = log.WithLogger(tc.Context, log.G(tc.Context).WithFields(logrus.Fields{
+		serverContexts[i] = log.WithLogger(tc.Context, log.G(tc.Context).WithFields(log.Fields{
 			"otherCAServer": i,
 		}))
 		startCAServer(serverContexts[i], otherServers[i])
@@ -1218,6 +1212,7 @@ func TestRootRotationReconciliationRace(t *testing.T) {
 			rotationCrossSigned []byte
 			rotationTLSInfo     *api.NodeTLSInfo
 			caRootCA            ca.RootCA
+			err                 error
 		)
 		rotationCert, rotationKey, err = cautils.CreateRootCertAndKey(fmt.Sprintf("root cn %d", i))
 		require.NoError(t, err)
