@@ -7,7 +7,6 @@ import (
 	"crypto/tls"
 	"crypto/x509"
 	"encoding/pem"
-	"io/ioutil"
 	"net"
 	"os"
 	"strings"
@@ -17,17 +16,16 @@ import (
 	cfcsr "github.com/cloudflare/cfssl/csr"
 	"github.com/cloudflare/cfssl/helpers"
 	"github.com/cloudflare/cfssl/initca"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	"github.com/docker/swarmkit/ca/pkcs8"
-	"github.com/docker/swarmkit/connectionbroker"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/ioutils"
-	"github.com/docker/swarmkit/log"
-	"github.com/docker/swarmkit/manager/state/store"
-	stateutils "github.com/docker/swarmkit/manager/state/testutils"
-	"github.com/docker/swarmkit/remotes"
-	"github.com/sirupsen/logrus"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	"github.com/moby/swarmkit/v2/ca/pkcs8"
+	"github.com/moby/swarmkit/v2/connectionbroker"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/ioutils"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	stateutils "github.com/moby/swarmkit/v2/manager/state/testutils"
+	"github.com/moby/swarmkit/v2/remotes"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
@@ -102,7 +100,7 @@ var External bool
 // NewTestCA is a helper method that creates a TestCA and a bunch of default
 // connections and security configs.
 func NewTestCA(t *testing.T, krwGenerators ...func(ca.CertPaths) *ca.KeyReadWriter) *TestCA {
-	tempdir, err := ioutil.TempDir("", "swarm-ca-test-")
+	tempdir, err := os.MkdirTemp("", "swarm-ca-test-")
 	if t != nil {
 		require.NoError(t, err)
 	}
@@ -122,7 +120,7 @@ func NewTestCA(t *testing.T, krwGenerators ...func(ca.CertPaths) *ca.KeyReadWrit
 // NewFIPSTestCA is a helper method that creates a mandatory fips TestCA and a bunch of default
 // connections and security configs.
 func NewFIPSTestCA(t *testing.T) *TestCA {
-	tempdir, err := ioutil.TempDir("", "swarm-ca-test-")
+	tempdir, err := os.MkdirTemp("", "swarm-ca-test-")
 	if t != nil {
 		require.NoError(t, err)
 	}
@@ -175,7 +173,7 @@ func newTestCA(t *testing.T, tempBaseDir string, apiRootCA api.RootCA, krwGenera
 	}
 
 	// Write the root certificate to disk, using decent permissions
-	err = ioutils.AtomicWriteFile(paths.RootCA.Cert, apiRootCA.CACert, 0644)
+	err = ioutils.AtomicWriteFile(paths.RootCA.Cert, apiRootCA.CACert, 0o644)
 	if t != nil {
 		require.NoError(t, err)
 	}
@@ -274,7 +272,7 @@ func newTestCA(t *testing.T, tempBaseDir string, apiRootCA api.RootCA, krwGenera
 	api.RegisterCAServer(grpcServer, caServer)
 	api.RegisterNodeCAServer(grpcServer, caServer)
 
-	fields := logrus.Fields{"testHasExternalCA": External}
+	fields := log.Fields{"testHasExternalCA": External}
 	if t != nil {
 		fields["testname"] = t.Name()
 	}
@@ -345,7 +343,7 @@ func createNode(s *store.MemoryStore, nodeID, role string, csr, cert []byte) err
 
 func genSecurityConfig(s *store.MemoryStore, rootCA ca.RootCA, krw *ca.KeyReadWriter, role, org, tmpDir string, nonSigningRoot bool) (*ca.SecurityConfig, func() error, error) {
 	req := &cfcsr.CertificateRequest{
-		KeyRequest: cfcsr.NewBasicKeyRequest(),
+		KeyRequest: cfcsr.NewKeyRequest(),
 	}
 
 	csr, key, err := cfcsr.ParseRequest(req)
@@ -369,10 +367,10 @@ func genSecurityConfig(s *store.MemoryStore, rootCA ca.RootCA, krw *ca.KeyReadWr
 	// If we were instructed to persist the files
 	if tmpDir != "" {
 		paths := ca.NewConfigPaths(tmpDir)
-		if err := ioutil.WriteFile(paths.Node.Cert, certChain, 0644); err != nil {
+		if err := os.WriteFile(paths.Node.Cert, certChain, 0o644); err != nil {
 			return nil, nil, err
 		}
-		if err := ioutil.WriteFile(paths.Node.Key, key, 0600); err != nil {
+		if err := os.WriteFile(paths.Node.Key, key, 0o600); err != nil {
 			return nil, nil, err
 		}
 	}
@@ -448,7 +446,7 @@ func CreateRootCertAndKey(rootCN string) ([]byte, []byte, error) {
 	// Create a simple CSR for the CA using the default CA validator and policy
 	req := cfcsr.CertificateRequest{
 		CN:         rootCN,
-		KeyRequest: cfcsr.NewBasicKeyRequest(),
+		KeyRequest: cfcsr.NewKeyRequest(),
 		CA:         &cfcsr.CAConfig{Expiry: ca.RootCAExpiration},
 	}
 
@@ -490,7 +488,7 @@ func ReDateCert(t *testing.T, cert, signerCert, signerKey []byte, notBefore, not
 func CreateCertFromSigner(rootCN string, priv crypto.Signer) ([]byte, error) {
 	req := cfcsr.CertificateRequest{
 		CN:         rootCN,
-		KeyRequest: &cfcsr.BasicKeyRequest{A: ca.RootKeyAlgo, S: ca.RootKeySize},
+		KeyRequest: &cfcsr.KeyRequest{A: ca.RootKeyAlgo, S: ca.RootKeySize},
 		CA:         &cfcsr.CAConfig{Expiry: ca.RootCAExpiration},
 	}
 	cert, _, err := initca.NewFromSigner(&req, priv)
