@@ -5,28 +5,25 @@ import (
 	"context"
 	"flag"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
+	"reflect"
 	"runtime"
 	"strings"
 	"testing"
 	"time"
 
-	"github.com/docker/swarmkit/node"
-
-	"reflect"
-
 	"github.com/cloudflare/cfssl/helpers"
 	events "github.com/docker/go-events"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager"
+	"github.com/moby/swarmkit/v2/node"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/pkg/errors"
-	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/require"
 )
 
@@ -44,9 +41,9 @@ func printTrace() {
 		bufferLen *= 2
 	}
 	buf = buf[:stackSize]
-	logrus.Error("===========================STACK TRACE===========================")
+	log.L.Error("===========================STACK TRACE===========================")
 	fmt.Println(string(buf))
-	logrus.Error("===========================STACK TRACE END=======================")
+	log.L.Error("===========================STACK TRACE END=======================")
 }
 
 func TestMain(m *testing.M) {
@@ -400,7 +397,7 @@ func TestDemotePromoteLeader(t *testing.T) {
 	numManager--
 	pollClusterReady(t, cl, numWorker, numManager)
 
-	//promote former leader back
+	// promote former leader back
 	require.NoError(t, cl.SetNodeRole(leader.node.NodeID(), api.NodeRoleManager))
 	// agents 1, managers 3
 	numWorker--
@@ -577,7 +574,7 @@ func TestForceNewCluster(t *testing.T) {
 
 	// generate an expired certificate
 	managerCertFile := filepath.Join(leader.stateDir, "certificates", "swarm-node.crt")
-	certBytes, err := ioutil.ReadFile(managerCertFile)
+	certBytes, err := os.ReadFile(managerCertFile)
 	require.NoError(t, err)
 	now := time.Now()
 	// we don't want it too expired, because it can't have expired before the root CA cert is valid
@@ -588,13 +585,13 @@ func TestForceNewCluster(t *testing.T) {
 	// restart node with an expired certificate while forcing a new cluster - it should start without error and the certificate should be renewed
 	nodeID := leader.node.NodeID()
 	require.NoError(t, leader.Pause(true))
-	require.NoError(t, ioutil.WriteFile(managerCertFile, expiredCertPEM, 0644))
+	require.NoError(t, os.WriteFile(managerCertFile, expiredCertPEM, 0o644))
 	require.NoError(t, cl.StartNode(nodeID))
 	pollClusterReady(t, cl, numWorker, numManager)
 	pollServiceReady(t, cl, sid, 2)
 
 	err = testutils.PollFuncWithTimeout(nil, func() error {
-		certBytes, err := ioutil.ReadFile(managerCertFile)
+		certBytes, err := os.ReadFile(managerCertFile)
 		if err != nil {
 			return err
 		}
@@ -611,7 +608,7 @@ func TestForceNewCluster(t *testing.T) {
 
 	// restart node with an expired certificate without forcing a new cluster - it should error on start
 	require.NoError(t, leader.Pause(true))
-	require.NoError(t, ioutil.WriteFile(managerCertFile, expiredCertPEM, 0644))
+	require.NoError(t, os.WriteFile(managerCertFile, expiredCertPEM, 0o644))
 	require.Error(t, cl.StartNode(nodeID))
 }
 
