@@ -3,16 +3,16 @@ package controlapi
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"testing"
 
-	"github.com/docker/swarmkit/api"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/identity"
-	raftutils "github.com/docker/swarmkit/manager/state/raft/testutils"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
-	"github.com/sirupsen/logrus"
+	"github.com/moby/swarmkit/v2/api"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/log"
+	raftutils "github.com/moby/swarmkit/v2/manager/state/raft/testutils"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc/codes"
@@ -451,8 +451,8 @@ func TestRemoveNodes(t *testing.T) {
 }
 
 func init() {
-	grpclog.SetLoggerV2(grpclog.NewLoggerV2(ioutil.Discard, ioutil.Discard, ioutil.Discard))
-	logrus.SetOutput(ioutil.Discard)
+	grpclog.SetLoggerV2(grpclog.NewLoggerV2(io.Discard, io.Discard, io.Discard))
+	log.L.Logger.SetOutput(io.Discard)
 }
 
 func getMap(t *testing.T, nodes []*api.Node) map[uint64]*api.ManagerStatus {
