@@ -1,16 +1,16 @@
 package controlapi
 
 import (
+	"context"
 	"strings"
 	"testing"
 
-	"github.com/docker/swarmkit/testutils"
-	"golang.org/x/net/context"
+	"github.com/moby/swarmkit/v2/testutils"
 	"google.golang.org/grpc/codes"
 
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager/state/store"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/manager/state/store"
 	"github.com/stretchr/testify/assert"
 )
 
