@@ -2,15 +2,14 @@ package manager
 
 import (
 	"context"
-	"io/ioutil"
 	"os"
 	"testing"
 
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	"github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/manager/state"
-	"github.com/docker/swarmkit/manager/state/store"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	"github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/manager/state"
+	"github.com/moby/swarmkit/v2/manager/state/store"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -18,17 +17,13 @@ import (
 func TestIsStateDirty(t *testing.T) {
 	ctx := context.Background()
 
-	temp, err := ioutil.TempFile("", "test-socket")
+	temp, err := os.CreateTemp("", "test-socket")
 	assert.NoError(t, err)
 	assert.NoError(t, temp.Close())
 	assert.NoError(t, os.Remove(temp.Name()))
 
 	defer os.RemoveAll(temp.Name())
 
-	stateDir, err := ioutil.TempDir("", "test-raft")
-	assert.NoError(t, err)
-	defer os.RemoveAll(stateDir)
-
 	tc := testutils.NewTestCA(t, func(p ca.CertPaths) *ca.KeyReadWriter {
 		return ca.NewKeyReadWriter(p, []byte("kek"), nil)
 	})
@@ -37,6 +32,7 @@ func TestIsStateDirty(t *testing.T) {
 	managerSecurityConfig, err := tc.NewNodeConfig(ca.ManagerRole)
 	assert.NoError(t, err)
 
+	stateDir := t.TempDir()
 	m, err := New(&Config{
 		RemoteAPI:        &RemoteAddrs{ListenAddr: "127.0.0.1:0"},
 		ControlAPI:       temp.Name(),
