@@ -6,10 +6,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	"io/ioutil"
 	"net"
-	"net/http"
-	"net/http/httptest"
 	"sync"
 	"testing"
 	"time"
@@ -18,16 +15,15 @@ import (
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/credentials"
 
-	"github.com/docker/docker/pkg/plugingetter"
-	"github.com/docker/docker/pkg/plugins"
 	"github.com/docker/go-events"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager/drivers"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/manager/drivers"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/node/plugin"
+	"github.com/moby/swarmkit/v2/testutils"
 	digest "github.com/opencontainers/go-digest"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -52,7 +48,6 @@ func (gd *grpcDispatcher) Close() {
 	}
 	gd.dispatcherServer.Stop()
 	gd.grpcServer.Stop()
-	gd.PluginGetter.Close()
 	gd.testCA.Stop()
 }
 
@@ -128,26 +123,22 @@ func (t *testCluster) MemoryStore() *store.MemoryStore {
 	return t.store
 }
 
-func startDispatcher(c *Config) (*grpcDispatcher, error) {
-	l, err := net.Listen("tcp", "127.0.0.1:0")
-	if err != nil {
-		return nil, err
-	}
+func startDispatcher(t *testing.T, c *Config) *grpcDispatcher {
+	t.Helper()
 
-	tca := cautils.NewTestCA(nil)
+	l, err := net.Listen("tcp", "127.0.0.1:0")
+	assert.NoError(t, err)
+
+	tca := cautils.NewTestCA(t)
 	tca.CAServer.Stop() // there is no need for the CA server to be running
 	agentSecurityConfig1, err := tca.NewNodeConfig(ca.WorkerRole)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
+
 	agentSecurityConfig2, err := tca.NewNodeConfig(ca.WorkerRole)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
+
 	managerSecurityConfig, err := tca.NewNodeConfig(ca.ManagerRole)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
 
 	serverOpts := []grpc.ServerOption{grpc.Creds(managerSecurityConfig.ServerTLSCreds)}
 
@@ -169,16 +160,15 @@ func startDispatcher(c *Config) (*grpcDispatcher, error) {
 		_ = s.Serve(l)
 	}()
 	go d.Run(context.Background())
-	if err := testutils.PollFuncWithTimeout(nil, func() error {
+	err = testutils.PollFuncWithTimeout(nil, func() error {
 		d.mu.Lock()
 		defer d.mu.Unlock()
 		if !d.isRunning() {
 			return fmt.Errorf("dispatcher is not running")
 		}
 		return nil
-	}, 5*time.Second); err != nil {
-		return nil, err
-	}
+	}, 5*time.Second)
+	assert.NoError(t, err)
 
 	clientOpts := []grpc.DialOption{grpc.WithTimeout(10 * time.Second)}
 	clientOpts1 := append(clientOpts, grpc.WithTransportCredentials(agentSecurityConfig1.ClientTLSCreds))
@@ -186,19 +176,13 @@ func startDispatcher(c *Config) (*grpcDispatcher, error) {
 	clientOpts3 := append(clientOpts, grpc.WithTransportCredentials(credentials.NewTLS(&tls.Config{InsecureSkipVerify: true})))
 
 	conn1, err := grpc.Dial(l.Addr().String(), clientOpts1...)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
 
 	conn2, err := grpc.Dial(l.Addr().String(), clientOpts2...)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
 
 	conn3, err := grpc.Dial(l.Addr().String(), clientOpts3...)
-	if err != nil {
-		return nil, err
-	}
+	assert.NoError(t, err)
 
 	clients := []api.DispatcherClient{api.NewDispatcherClient(conn1), api.NewDispatcherClient(conn2), api.NewDispatcherClient(conn3)}
 	securityConfigs := []*ca.SecurityConfig{agentSecurityConfig1, agentSecurityConfig2, managerSecurityConfig}
@@ -213,14 +197,13 @@ func startDispatcher(c *Config) (*grpcDispatcher, error) {
 		testCA:           tca,
 		testCluster:      tc,
 		PluginGetter:     driverGetter,
-	}, nil
+	}
 }
 
 func TestRegisterTwice(t *testing.T) {
 	cfg := DefaultConfig()
 	cfg.RateLimitPeriod = 0
-	gd, err := startDispatcher(cfg)
-	assert.NoError(t, err)
+	gd := startDispatcher(t, cfg)
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -248,8 +231,7 @@ func TestRegisterTwice(t *testing.T) {
 func TestRegisterExceedRateLimit(t *testing.T) {
 	t.Parallel()
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	for i := 0; i < 3; i++ {
@@ -271,8 +253,7 @@ func TestRegisterExceedRateLimit(t *testing.T) {
 }
 
 func TestRegisterNoCert(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	// This client has no certificates, this should fail
@@ -288,8 +269,7 @@ func TestHeartbeat(t *testing.T) {
 	cfg := DefaultConfig()
 	cfg.HeartbeatPeriod = 500 * time.Millisecond
 	cfg.HeartbeatEpsilon = 0
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -334,8 +314,7 @@ func TestHeartbeat(t *testing.T) {
 }
 
 func TestHeartbeatNoCert(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	// heartbeat without correct SessionID should fail
@@ -350,8 +329,7 @@ func TestHeartbeatTimeout(t *testing.T) {
 	cfg := DefaultConfig()
 	cfg.HeartbeatPeriod = 100 * time.Millisecond
 	cfg.HeartbeatEpsilon = 0
-	gd, err := startDispatcher(cfg)
-	assert.NoError(t, err)
+	gd := startDispatcher(t, cfg)
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -387,8 +365,7 @@ func TestHeartbeatTimeout(t *testing.T) {
 }
 
 func TestHeartbeatUnregistered(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 	resp, err := gd.Clients[0].Heartbeat(context.Background(), &api.HeartbeatRequest{})
 	assert.Nil(t, resp)
@@ -400,8 +377,7 @@ func TestHeartbeatUnregistered(t *testing.T) {
 func TestAssignmentsErrorsIfNoSessionID(t *testing.T) {
 	t.Parallel()
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	// without correct SessionID should fail
@@ -420,13 +396,16 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 	t.Parallel()
 
 	const (
-		secretDriver        = "secret-driver"
-		existingSecretName  = "existing-secret"
-		serviceName         = "service-name"
-		serviceHostname     = "service-hostname"
-		serviceEndpointMode = 2
+		secretDriver                 = "secret-driver"
+		existingSecretName           = "existing-secret"
+		doNotReuseExistingSecretName = "do-not-reuse-existing-secret"
+		errSecretName                = "err-secret"
+		serviceName                  = "service-name"
+		serviceHostname              = "service-hostname"
+		serviceEndpointMode          = 2
 	)
 	secretValue := []byte("custom-secret-value")
+	doNotReuseSecretValue := []byte("custom-do-not-reuse-secret-value")
 	serviceLabels := map[string]string{
 		"label-name": "label-value",
 	}
@@ -434,15 +413,14 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 	portConfig := drivers.PortConfig{Name: "port", PublishMode: 5, TargetPort: 80, Protocol: 10, PublishedPort: 8080}
 
 	responses := map[string]*drivers.SecretsProviderResponse{
-		existingSecretName: {Value: secretValue},
+		existingSecretName:           {Value: secretValue},
+		doNotReuseExistingSecretName: {Value: doNotReuseSecretValue, DoNotReuse: true},
+		errSecretName:                {Err: "Error from driver"},
 	}
 
-	mux := http.NewServeMux()
-	mux.HandleFunc(drivers.SecretsProviderAPI, func(w http.ResponseWriter, r *http.Request) {
-		defer r.Body.Close()
-		body, err := ioutil.ReadAll(r.Body)
+	var mux MockPluginClient
+	mux.HandleFunc(drivers.SecretsProviderAPI, func(body []byte) (interface{}, error) {
 		var request drivers.SecretsProviderRequest
-		assert.NoError(t, err)
 		assert.NoError(t, json.Unmarshal(body, &request))
 		response := responses[request.SecretName]
 		assert.Equal(t, serviceName, request.ServiceName)
@@ -452,15 +430,12 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 		assert.EqualValues(t, portConfig, request.ServiceEndpointSpec.Ports[0])
 		assert.EqualValues(t, serviceLabels, request.ServiceLabels)
 		assert.NotNil(t, response)
-		resp, err := json.Marshal(response)
-		assert.NoError(t, err)
-		w.Write(resp)
+		return response, nil
 	})
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
-	assert.NoError(t, gd.PluginGetter.SetupPlugin(secretDriver, mux))
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
+	assert.NoError(t, gd.PluginGetter.SetupPlugin(secretDriver, &mux))
 
 	expectedSessionID, nodeID := getSessionAndNodeID(t, gd.Clients[0])
 
@@ -471,13 +446,27 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 			Driver:      &api.Driver{Name: secretDriver},
 		},
 	}
+	doNotReuseSecret := &api.Secret{
+		ID: "driverDoNotReuseSecret",
+		Spec: api.SecretSpec{
+			Annotations: api.Annotations{Name: doNotReuseExistingSecretName},
+			Driver:      &api.Driver{Name: secretDriver},
+		},
+	}
+	errSecret := &api.Secret{
+		ID: "driverErrSecret",
+		Spec: api.SecretSpec{
+			Annotations: api.Annotations{Name: errSecretName},
+			Driver:      &api.Driver{Name: secretDriver},
+		},
+	}
 	config := &api.Config{
 		ID: "config",
 		Spec: api.ConfigSpec{
 			Data: []byte("config"),
 		},
 	}
-	spec := taskSpecFromDependencies(secret, config)
+	spec := taskSpecFromDependencies(secret, doNotReuseSecret, errSecret, config)
 	spec.GetContainer().Hostname = serviceHostname
 	task := &api.Task{
 		NodeID:       nodeID,
@@ -505,8 +494,10 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 		},
 	}
 
-	err = gd.Store.Update(func(tx store.Tx) error {
+	err := gd.Store.Update(func(tx store.Tx) error {
 		assert.NoError(t, store.CreateSecret(tx, secret))
+		assert.NoError(t, store.CreateSecret(tx, doNotReuseSecret))
+		assert.NoError(t, store.CreateSecret(tx, errSecret))
 		assert.NoError(t, store.CreateConfig(tx, config))
 		assert.NoError(t, store.CreateTask(tx, task))
 		return nil
@@ -520,13 +511,292 @@ func TestAssignmentsSecretDriver(t *testing.T) {
 	resp, err := stream.Recv()
 	assert.NoError(t, err)
 
-	_, _, secretChanges := splitChanges(resp.Changes)
-	assert.Len(t, secretChanges, 1)
+	_, _, secretChanges, _ := splitChanges(resp.Changes)
+	assert.Len(t, secretChanges, 2)
 	for _, s := range secretChanges {
-		assert.Equal(t, secretValue, s.Spec.Data)
+		if s.ID == "driverSecret" {
+			assert.Equal(t, secretValue, s.Spec.Data)
+		} else if s.ID == "driverDoNotReuseSecret" {
+			assert.Fail(t, "Secret with DoNotReuse==true should not retain its original ID in the assignment", "%s != %s", "driverDoNotReuseSecret", s.ID)
+		} else {
+			taskSpecificID := fmt.Sprintf("%s.%s", "driverDoNotReuseSecret", task.ID)
+			assert.Equal(t, taskSpecificID, s.ID)
+			assert.Equal(t, doNotReuseSecretValue, s.Spec.Data)
+		}
 	}
 }
 
+// TestAssignmentsWithVolume tests that Assignments correctly sends down
+// volumes.
+func TestAssignmentsWithVolume(t *testing.T) {
+	gd := startDispatcher(t, DefaultConfig())
+	defer gd.Close()
+
+	expectedSessionID, nodeID := getSessionAndNodeID(t, gd.Clients[0])
+
+	volumes := []*api.Volume{
+		{
+			ID: "volumeID0",
+			Spec: api.VolumeSpec{
+				Annotations: api.Annotations{
+					Name: "volumeName",
+				},
+				Driver: &api.Driver{
+					Name: "someDriver",
+				},
+				Secrets: []*api.VolumeSecret{
+					{
+						Key:    "volumeSecret0",
+						Secret: "secret0",
+					}, {
+						Key:    "volumeSecret1",
+						Secret: "secret1",
+					},
+				},
+			},
+			VolumeInfo: &api.VolumeInfo{
+				VolumeID: "csiID0",
+				VolumeContext: map[string]string{
+					"volumeID": "0",
+				},
+			},
+			PublishStatus: []*api.VolumePublishStatus{
+				{
+					NodeID: nodeID,
+					State:  api.VolumePublishStatus_PENDING_PUBLISH,
+				},
+			},
+		}, {
+			ID: "volumeID1",
+			Spec: api.VolumeSpec{
+				Annotations: api.Annotations{
+					Name: "volumeOtherName",
+				},
+				Group: "volumeGroup",
+				Driver: &api.Driver{
+					Name: "someDriver",
+				},
+				Secrets: []*api.VolumeSecret{
+					{
+						Key:    "volumeSecret0",
+						Secret: "secret0",
+					}, {
+						Key:    "volumeSecret2",
+						Secret: "secret2",
+					},
+				},
+			},
+			VolumeInfo: &api.VolumeInfo{
+				VolumeID: "csiID1",
+				VolumeContext: map[string]string{
+					"volumeID": "1",
+				},
+			},
+			PublishStatus: []*api.VolumePublishStatus{
+				{
+					NodeID: nodeID,
+					State:  api.VolumePublishStatus_PUBLISHED,
+					PublishContext: map[string]string{
+						"published": "yes",
+						"volumeID":  "1",
+					},
+				},
+			},
+		},
+	}
+
+	secrets := []*api.Secret{
+		{
+			ID: "secret0",
+			Spec: api.SecretSpec{
+				Annotations: api.Annotations{
+					Name: "secretName0",
+				},
+				Data: []byte("secret0 data"),
+			},
+		}, {
+			ID: "secret1",
+			Spec: api.SecretSpec{
+				Annotations: api.Annotations{
+					Name: "secretName1",
+				},
+				Data: []byte("secret1 data"),
+			},
+		}, {
+			ID: "secret2",
+			Spec: api.SecretSpec{
+				Annotations: api.Annotations{
+					Name: "secretName2",
+				},
+				Data: []byte("secret2 data"),
+			},
+		},
+	}
+
+	task := &api.Task{
+		ID:     "task1",
+		NodeID: nodeID,
+		Status: api.TaskStatus{
+			State: api.TaskStateAssigned,
+		},
+		DesiredState: api.TaskStateRunning,
+		Spec: api.TaskSpec{
+			Runtime: &api.TaskSpec_Container{
+				Container: &api.ContainerSpec{
+					Mounts: []api.Mount{
+						{
+							Type:   api.MountTypeCluster,
+							Source: "volumeName",
+							Target: "/foo",
+						}, {
+							Type:   api.MountTypeCluster,
+							Source: "group:volumeGroup",
+							Target: "/bar",
+						},
+					},
+					Secrets: []*api.SecretReference{
+						{
+							SecretID:   "secret1",
+							SecretName: "secretName1",
+							Target: &api.SecretReference_File{
+								File: &api.FileTarget{
+									Name: "somefile",
+								},
+							},
+						},
+					},
+				},
+			},
+			ResourceReferences: []api.ResourceReference{
+				{
+					ResourceID:   "secret1",
+					ResourceType: api.ResourceType_SECRET,
+				},
+			},
+		},
+		Volumes: []*api.VolumeAttachment{
+			{
+				ID:     "volumeID0",
+				Source: "volumeName",
+				Target: "/foo",
+			}, {
+				ID:     "volumeID1",
+				Source: "group:volumeGroup",
+				Target: "/bar",
+			},
+		},
+	}
+
+	err := gd.Store.Update(func(tx store.Tx) error {
+		for _, secret := range secrets {
+			if err := store.CreateSecret(tx, secret); err != nil {
+				return err
+			}
+		}
+
+		for _, volume := range volumes {
+			if err := store.CreateVolume(tx, volume); err != nil {
+				return err
+			}
+		}
+
+		return store.CreateTask(tx, task)
+	})
+	assert.NoError(t, err)
+
+	stream, err := gd.Clients[0].Assignments(
+		context.Background(),
+		&api.AssignmentsRequest{SessionID: expectedSessionID},
+	)
+	assert.NoError(t, err)
+	defer stream.CloseSend()
+
+	time.Sleep(100 * time.Millisecond)
+
+	resp, err := stream.Recv()
+	assert.NoError(t, err)
+
+	verifyChanges(t, resp.Changes, []changeExpectations{
+		{
+			action:  api.AssignmentChange_AssignmentActionUpdate,
+			tasks:   []*api.Task{task},
+			secrets: secrets,
+			volumes: []*api.VolumeAssignment{
+				{
+					ID:       "volumeID1",
+					VolumeID: "csiID1",
+					Driver: &api.Driver{
+						Name: "someDriver",
+					},
+					VolumeContext: map[string]string{
+						"volumeID": "1",
+					},
+					PublishContext: map[string]string{
+						"published": "yes",
+						"volumeID":  "1",
+					},
+					Secrets: []*api.VolumeSecret{
+						{
+							Key:    "volumeSecret0",
+							Secret: "secret0",
+						}, {
+							Key:    "volumeSecret2",
+							Secret: "secret2",
+						},
+					},
+				},
+			},
+		},
+	})
+
+	// now update the volume to be published
+	assert.NoError(t, gd.Store.Update(func(tx store.Tx) error {
+		v := store.GetVolume(tx, "volumeID0")
+		v.PublishStatus[0].State = api.VolumePublishStatus_PUBLISHED
+		v.PublishStatus[0].PublishContext = map[string]string{
+			"published": "yes",
+			"volumeID":  "0",
+		}
+		return store.UpdateVolume(tx, v)
+	}))
+
+	// now see if we get a volume assignment
+	resp, err = stream.Recv()
+	assert.NoError(t, err)
+
+	_, _, _, volumeChanges := splitChanges(resp.Changes)
+	assert.Len(t, volumeChanges, 1)
+	assert.Equal(t,
+		volumeChanges[idAndAction{
+			id:     "volumeID0",
+			action: api.AssignmentChange_AssignmentActionUpdate,
+		}],
+		&api.VolumeAssignment{
+			ID:       "volumeID0",
+			VolumeID: "csiID0",
+			Driver: &api.Driver{
+				Name: "someDriver",
+			},
+			VolumeContext: map[string]string{
+				"volumeID": "0",
+			},
+			PublishContext: map[string]string{
+				"published": "yes",
+				"volumeID":  "0",
+			},
+			Secrets: []*api.VolumeSecret{
+				{
+					Key:    "volumeSecret0",
+					Secret: "secret0",
+				}, {
+					Key:    "volumeSecret1",
+					Secret: "secret1",
+				},
+			},
+		},
+	)
+}
+
 // When connecting to a dispatcher to get Assignments, if there are tasks already in the store,
 // Assignments will send down any existing node tasks > ASSIGNED, and any secrets
 // for said tasks that are <= RUNNING (if the secrets exist)
@@ -544,15 +814,14 @@ func TestAssignmentsInitialNodeTasks(t *testing.T) {
 }
 
 func testAssignmentsInitialNodeTasksWithGivenTasks(t *testing.T, genTasks taskGeneratorFunc) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	expectedSessionID, nodeID := getSessionAndNodeID(t, gd.Clients[0])
 
 	// create the relevant secrets and tasks
 	secrets, configs, resourceRefs, tasks := genTasks(t, nodeID)
-	err = gd.Store.Update(func(tx store.Tx) error {
+	err := gd.Store.Update(func(tx store.Tx) error {
 		for _, secret := range secrets {
 			assert.NoError(t, store.CreateSecret(tx, secret))
 		}
@@ -748,8 +1017,7 @@ func TestAssignmentsAddingTasks(t *testing.T) {
 }
 
 func testAssignmentsAddingTasksWithGivenTasks(t *testing.T, genTasks taskGeneratorFunc) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	expectedSessionID, nodeID := getSessionAndNodeID(t, gd.Clients[0])
@@ -879,15 +1147,14 @@ func TestAssignmentsDependencyUpdateAndDeletion(t *testing.T) {
 }
 
 func testAssignmentsDependencyUpdateAndDeletionWithGivenTasks(t *testing.T, genTasks taskGeneratorFunc) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	expectedSessionID, nodeID := getSessionAndNodeID(t, gd.Clients[0])
 
 	// create the relevant secrets and tasks
 	secrets, configs, resourceRefs, tasks := genTasks(t, nodeID)
-	err = gd.Store.Update(func(tx store.Tx) error {
+	err := gd.Store.Update(func(tx store.Tx) error {
 		for _, secret := range secrets {
 			if store.GetSecret(tx, secret.ID) == nil {
 				assert.NoError(t, store.CreateSecret(tx, secret))
@@ -994,8 +1261,7 @@ func testAssignmentsDependencyUpdateAndDeletionWithGivenTasks(t *testing.T, genT
 func TestTasksStatusChange(t *testing.T) {
 	t.Parallel()
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -1085,8 +1351,7 @@ func TestTasksStatusChange(t *testing.T) {
 }
 
 func TestTasksBatch(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -1155,8 +1420,7 @@ func TestTasksBatch(t *testing.T) {
 }
 
 func TestTasksNoCert(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	stream, err := gd.Clients[2].Assignments(context.Background(), &api.AssignmentsRequest{})
@@ -1168,8 +1432,7 @@ func TestTasksNoCert(t *testing.T) {
 }
 
 func TestTaskUpdate(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var (
@@ -1211,7 +1474,7 @@ func TestTaskUpdate(t *testing.T) {
 			State: api.TaskStateShutdown,
 		},
 	}
-	err = gd.Store.Update(func(tx store.Tx) error {
+	err := gd.Store.Update(func(tx store.Tx) error {
 		assert.NoError(t, store.CreateTask(tx, testTask1))
 		assert.NoError(t, store.CreateTask(tx, testTask2))
 		assert.NoError(t, store.CreateTask(tx, testTask3))
@@ -1292,14 +1555,13 @@ func TestTaskUpdate(t *testing.T) {
 }
 
 func TestTaskUpdateNoCert(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	testTask1 := &api.Task{
 		ID: "testTask1",
 	}
-	err = gd.Store.Update(func(tx store.Tx) error {
+	err := gd.Store.Update(func(tx store.Tx) error {
 		assert.NoError(t, store.CreateTask(tx, testTask1))
 		return nil
 	})
@@ -1322,11 +1584,19 @@ func TestTaskUpdateNoCert(t *testing.T) {
 }
 
 func TestSession(t *testing.T) {
-	cfg := DefaultConfig()
-	gd, err := startDispatcher(cfg)
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
+	// update the cluster to include some csi plugins
+	err := gd.Store.Update(func(tx store.Tx) error {
+		cluster := store.GetCluster(tx, gd.testCA.Organization)
+		if cluster == nil {
+			return errors.New("no cluster")
+		}
+		return store.UpdateCluster(tx, cluster)
+	})
+	require.NoError(t, err)
+
 	stream, err := gd.Clients[0].Session(context.Background(), &api.SessionRequest{})
 	assert.NoError(t, err)
 	stream.CloseSend()
@@ -1337,9 +1607,7 @@ func TestSession(t *testing.T) {
 }
 
 func TestSessionNoCert(t *testing.T) {
-	cfg := DefaultConfig()
-	gd, err := startDispatcher(cfg)
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	stream, err := gd.Clients[2].Session(context.Background(), &api.SessionRequest{})
@@ -1364,10 +1632,11 @@ type idAndAction struct {
 	action api.AssignmentChange_AssignmentAction
 }
 
-func splitChanges(changes []*api.AssignmentChange) (map[idAndAction]*api.Task, map[idAndAction]*api.Config, map[idAndAction]*api.Secret) {
+func splitChanges(changes []*api.AssignmentChange) (map[idAndAction]*api.Task, map[idAndAction]*api.Config, map[idAndAction]*api.Secret, map[idAndAction]*api.VolumeAssignment) {
 	tasks := make(map[idAndAction]*api.Task)
 	secrets := make(map[idAndAction]*api.Secret)
 	configs := make(map[idAndAction]*api.Config)
+	volumes := make(map[idAndAction]*api.VolumeAssignment)
 	for _, change := range changes {
 		task := change.Assignment.GetTask()
 		if task != nil {
@@ -1381,23 +1650,28 @@ func splitChanges(changes []*api.AssignmentChange) (map[idAndAction]*api.Task, m
 		if config != nil {
 			configs[idAndAction{id: config.ID, action: change.Action}] = config
 		}
+		volume := change.Assignment.GetVolume()
+		if volume != nil {
+			volumes[idAndAction{id: volume.ID, action: change.Action}] = volume
+		}
 	}
 
-	return tasks, configs, secrets
+	return tasks, configs, secrets, volumes
 }
 
 type changeExpectations struct {
 	tasks   []*api.Task
 	secrets []*api.Secret
 	configs []*api.Config
+	volumes []*api.VolumeAssignment
 	action  api.AssignmentChange_AssignmentAction
 }
 
 // Ensures that the changes contain the following actions for the following tasks/secrets/configs
 func verifyChanges(t *testing.T, changes []*api.AssignmentChange, expectations []changeExpectations) {
-	taskChanges, configChanges, secretChanges := splitChanges(changes)
+	taskChanges, configChanges, secretChanges, volumeChanges := splitChanges(changes)
 
-	var expectedTasks, expectedSecrets, expectedConfigs int
+	var expectedTasks, expectedSecrets, expectedConfigs, expectedVolumes int
 	for _, c := range expectations {
 		for _, task := range c.tasks {
 			expectedTasks++
@@ -1416,12 +1690,18 @@ func verifyChanges(t *testing.T, changes []*api.AssignmentChange, expectations [
 			index := idAndAction{id: config.ID, action: c.action}
 			require.NotNil(t, configChanges[index], "missing config change %v", index)
 		}
+		for _, volume := range c.volumes {
+			expectedVolumes++
+			index := idAndAction{id: volume.ID, action: c.action}
+			require.NotNil(t, volumeChanges[index], "missing volume change %v", index)
+		}
 	}
 
 	require.Len(t, taskChanges, expectedTasks)
 	require.Len(t, secretChanges, expectedSecrets)
 	require.Len(t, configChanges, expectedConfigs)
-	require.Len(t, changes, expectedTasks+expectedSecrets+expectedConfigs)
+	require.Len(t, volumeChanges, expectedVolumes)
+	require.Len(t, changes, expectedTasks+expectedSecrets+expectedConfigs+expectedVolumes)
 }
 
 // filter all tasks by task state, which is given by a function because it's hard to take a range of constants
@@ -1455,7 +1735,7 @@ func getResourcesFromReferences(gd *grpcDispatcher, resourceRefs []*api.Resource
 	return referencedSecrets, referencedConfigs
 }
 
-// filters all dependencies (secrets, configs); dependencies should be in `inTasks`, but not be in `notInTasks``
+// filters all dependencies (secrets, configs); dependencies should be in inTasks, but not be in notInTasks
 func filterDependencies(secrets []*api.Secret, configs []*api.Config, inTasks, notInTasks []*api.Task) ([]*api.Secret, []*api.Config) {
 	var (
 		wantSecrets, wantConfigs = make(map[string]struct{}), make(map[string]struct{})
@@ -1715,8 +1995,7 @@ var taskStatesInOrder = []api.TaskState{
 func TestOldTasks(t *testing.T) {
 	t.Parallel()
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -1813,8 +2092,7 @@ func TestOldTasks(t *testing.T) {
 func TestOldTasksStatusChange(t *testing.T) {
 	t.Parallel()
 
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -1903,8 +2181,7 @@ func TestOldTasksStatusChange(t *testing.T) {
 }
 
 func TestOldTasksBatch(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	var expectedSessionID string
@@ -1960,8 +2237,7 @@ func TestOldTasksBatch(t *testing.T) {
 }
 
 func TestOldTasksNoCert(t *testing.T) {
-	gd, err := startDispatcher(DefaultConfig())
-	assert.NoError(t, err)
+	gd := startDispatcher(t, DefaultConfig())
 	defer gd.Close()
 
 	stream, err := gd.Clients[2].Tasks(context.Background(), &api.TasksRequest{})
@@ -1975,8 +2251,7 @@ func TestOldTasksNoCert(t *testing.T) {
 func TestClusterUpdatesSendMessages(t *testing.T) {
 	cfg := DefaultConfig()
 	cfg.RateLimitPeriod = 0
-	gd, err := startDispatcher(cfg)
-	require.NoError(t, err)
+	gd := startDispatcher(t, cfg)
 	defer gd.Close()
 
 	stream, err := gd.Clients[0].Session(context.Background(), &api.SessionRequest{})
@@ -2048,59 +2323,41 @@ func TestClusterUpdatesSendMessages(t *testing.T) {
 
 // mockPluginGetter enables mocking the server plugin getter with customized plugins
 type mockPluginGetter struct {
-	addr   string
-	server *httptest.Server
 	name   string
-	plugin plugingetter.CompatPlugin
+	plugin plugin.Plugin
 }
 
+var _ plugin.Getter = &mockPluginGetter{}
+
 // SetupPlugin setup a new plugin - the same plugin wil always return in all calls
-func (m *mockPluginGetter) SetupPlugin(name string, handler http.Handler) error {
-	m.server = httptest.NewServer(handler)
-	client, err := plugins.NewClient(m.server.URL, nil)
-	if err != nil {
-		return err
-	}
+func (m *mockPluginGetter) SetupPlugin(name string, client plugin.Client) error {
 	m.plugin = NewMockPlugin(m.name, client)
 	m.name = name
 	return nil
 }
 
-// Close closes the mock plugin getter
-func (m *mockPluginGetter) Close() {
-	if m.server == nil {
-		return
-	}
-	m.server.Close()
-}
-
-func (m *mockPluginGetter) Get(name, capability string, mode int) (plugingetter.CompatPlugin, error) {
+func (m *mockPluginGetter) Get(name, capability string) (plugin.Plugin, error) {
 	if name != m.name {
 		return nil, fmt.Errorf("plugin with name %s not defined", name)
 	}
 	return m.plugin, nil
 }
-func (m *mockPluginGetter) GetAllByCap(capability string) ([]plugingetter.CompatPlugin, error) {
-	return nil, nil
-}
-func (m *mockPluginGetter) GetAllManagedPluginsByCap(capability string) []plugingetter.CompatPlugin {
+func (m *mockPluginGetter) GetAllManagedPluginsByCap(capability string) []plugin.Plugin {
 	return nil
 }
-func (m *mockPluginGetter) Handle(capability string, callback func(string, *plugins.Client)) {
-}
 
 // MockPlugin mocks a v2 docker plugin
 type MockPlugin struct {
-	client *plugins.Client
+	client plugin.Client
 	name   string
 }
 
 // NewMockPlugin creates a new v2 plugin fake (returns the specified client and name for all calls)
-func NewMockPlugin(name string, client *plugins.Client) *MockPlugin {
+func NewMockPlugin(name string, client plugin.Client) *MockPlugin {
 	return &MockPlugin{name: name, client: client}
 }
 
-func (m *MockPlugin) Client() *plugins.Client {
+func (m *MockPlugin) Client() plugin.Client {
 	return m.client
 }
 func (m *MockPlugin) Name() string {
@@ -2109,10 +2366,39 @@ func (m *MockPlugin) Name() string {
 func (m *MockPlugin) ScopedPath(_ string) string {
 	return ""
 }
-func (m *MockPlugin) BasePath() string {
-	return ""
 
+type MockPluginHandlerFn func(argsJSON []byte) (interface{}, error)
+
+type MockPluginClient struct {
+	handlers map[string]MockPluginHandlerFn
 }
-func (m *MockPlugin) IsV1() bool {
-	return false
+
+func (mc *MockPluginClient) HandleFunc(method string, fn MockPluginHandlerFn) {
+	if mc.handlers == nil {
+		mc.handlers = make(map[string]MockPluginHandlerFn)
+	}
+	if _, ok := mc.handlers[method]; ok {
+		panic(fmt.Sprintf("handler for %s already exists", method))
+	}
+	mc.handlers[method] = fn
+}
+
+func (mc *MockPluginClient) Call(method string, args, ret interface{}) error {
+	fn, ok := mc.handlers[method]
+	if !ok {
+		return fmt.Errorf("no handler for %s", method)
+	}
+	jsonArgs, err := json.Marshal(args)
+	if err != nil {
+		return err
+	}
+	res, err := fn(jsonArgs)
+	if err != nil {
+		return err
+	}
+	jsonRes, err := json.Marshal(res)
+	if err != nil {
+		return fmt.Errorf("error marshalling response: %v", err)
+	}
+	return json.Unmarshal(jsonRes, ret)
 }
