@@ -5,20 +5,20 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/docker/swarmkit/manager/orchestrator"
+	"github.com/moby/swarmkit/v2/manager/orchestrator"
 
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager/orchestrator/replicated"
-	"github.com/docker/swarmkit/manager/orchestrator/testutils"
-	"github.com/docker/swarmkit/manager/state"
-	"github.com/docker/swarmkit/manager/state/store"
 	gogotypes "github.com/gogo/protobuf/types"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/manager/orchestrator/replicated"
+	"github.com/moby/swarmkit/v2/manager/orchestrator/testutils"
+	"github.com/moby/swarmkit/v2/manager/state"
+	"github.com/moby/swarmkit/v2/manager/state/store"
 )
 
 // TestTaskReaperInit tests that the task reaper correctly cleans up tasks when
