@@ -4,7 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"math/rand"
 	"net"
 	"os"
@@ -13,25 +13,25 @@ import (
 	"testing"
 	"time"
 
+	"github.com/moby/swarmkit/v2/log"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/grpclog"
 	"google.golang.org/grpc/status"
 
 	"code.cloudfoundry.org/clock/fakeclock"
-	"github.com/coreos/etcd/raft/raftpb"
-	"github.com/coreos/etcd/wal"
-	"github.com/docker/swarmkit/api"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/manager/state"
-	"github.com/docker/swarmkit/manager/state/raft"
-	raftutils "github.com/docker/swarmkit/manager/state/raft/testutils"
-	"github.com/docker/swarmkit/manager/state/raft/transport"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
-	"github.com/sirupsen/logrus"
+	"github.com/moby/swarmkit/v2/api"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/manager/state"
+	"github.com/moby/swarmkit/v2/manager/state/raft"
+	raftutils "github.com/moby/swarmkit/v2/manager/state/raft/testutils"
+	"github.com/moby/swarmkit/v2/manager/state/raft/transport"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"go.etcd.io/etcd/raft/v3/raftpb"
+	"go.etcd.io/etcd/server/v3/wal"
 )
 
 const (
@@ -41,8 +41,8 @@ const (
 
 func init() {
 	store.WedgeTimeout = 3 * time.Second
-	grpclog.SetLoggerV2(grpclog.NewLoggerV2(ioutil.Discard, ioutil.Discard, ioutil.Discard))
-	logrus.SetOutput(ioutil.Discard)
+	grpclog.SetLoggerV2(grpclog.NewLoggerV2(io.Discard, io.Discard, io.Discard))
+	log.L.Logger.SetOutput(io.Discard)
 }
 
 var tc *cautils.TestCA
