@@ -4,25 +4,33 @@ import (
 	"bytes"
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
+	"strconv"
 	"testing"
 
-	"github.com/coreos/etcd/raft/raftpb"
-	"github.com/coreos/etcd/wal/walpb"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/manager/encryption"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/manager/encryption"
 	"github.com/stretchr/testify/require"
+	"go.etcd.io/etcd/raft/v3/raftpb"
+	"go.etcd.io/etcd/server/v3/wal/walpb"
 )
 
 var _ WALFactory = walCryptor{}
 
+var (
+	confState = raftpb.ConfState{
+		Voters:    []uint64{0x00ffca74},
+		AutoLeave: false,
+	}
+)
+
 // Generates a bunch of WAL test data
-func makeWALData(index uint64, term uint64) ([]byte, []raftpb.Entry, walpb.Snapshot) {
+func makeWALData(index uint64, term uint64, state *raftpb.ConfState) ([]byte, []raftpb.Entry, walpb.Snapshot) {
 	wsn := walpb.Snapshot{
-		Index: index,
-		Term:  term,
+		Index:     index,
+		Term:      term,
+		ConfState: state,
 	}
 
 	var entries []raftpb.Entry
@@ -38,10 +46,8 @@ func makeWALData(index uint64, term uint64) ([]byte, []raftpb.Entry, walpb.Snaps
 }
 
 func createWithWAL(t *testing.T, w WALFactory, metadata []byte, startSnap walpb.Snapshot, entries []raftpb.Entry) string {
-	walDir, err := ioutil.TempDir("", "waltests")
-	require.NoError(t, err)
-	require.NoError(t, os.RemoveAll(walDir))
-
+	t.Helper()
+	walDir := t.TempDir()
 	walWriter, err := w.Create(walDir, metadata)
 	require.NoError(t, err)
 
@@ -54,7 +60,7 @@ func createWithWAL(t *testing.T, w WALFactory, metadata []byte, startSnap walpb.
 
 // WAL can read entries are not wrapped, but not encrypted
 func TestReadAllWrappedNoEncryption(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 	wrappedEntries := make([]raftpb.Entry, len(entries))
 	for i, entry := range entries {
 		r := api.MaybeEncryptedRecord{Data: entry.Data}
@@ -65,7 +71,6 @@ func TestReadAllWrappedNoEncryption(t *testing.T) {
 	}
 
 	tempdir := createWithWAL(t, OriginalWAL, metadata, snapshot, wrappedEntries)
-	defer os.RemoveAll(tempdir)
 
 	c := NewWALFactory(encryption.NoopCrypter, encryption.NoopCrypter)
 	wrapped, err := c.Open(tempdir, snapshot)
@@ -82,7 +87,7 @@ func TestReadAllWrappedNoEncryption(t *testing.T) {
 
 // When reading WAL, if the decrypter can't read the encryption type, errors
 func TestReadAllNoSupportedDecrypter(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 	for i, entry := range entries {
 		r := api.MaybeEncryptedRecord{Data: entry.Data, Algorithm: api.MaybeEncryptedRecord_Algorithm(-3)}
 		data, err := r.Marshal()
@@ -91,7 +96,6 @@ func TestReadAllNoSupportedDecrypter(t *testing.T) {
 	}
 
 	tempdir := createWithWAL(t, OriginalWAL, metadata, snapshot, entries)
-	defer os.RemoveAll(tempdir)
 
 	c := NewWALFactory(encryption.NoopCrypter, encryption.NoopCrypter)
 	wrapped, err := c.Open(tempdir, snapshot)
@@ -107,7 +111,7 @@ func TestReadAllNoSupportedDecrypter(t *testing.T) {
 // entry is incorrectly encryptd, an error is returned
 func TestReadAllEntryIncorrectlyEncrypted(t *testing.T) {
 	crypter := &meowCrypter{}
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 
 	// metadata is correctly encryptd, but entries are not meow-encryptd
 	for i, entry := range entries {
@@ -118,7 +122,6 @@ func TestReadAllEntryIncorrectlyEncrypted(t *testing.T) {
 	}
 
 	tempdir := createWithWAL(t, OriginalWAL, metadata, snapshot, entries)
-	defer os.RemoveAll(tempdir)
 
 	c := NewWALFactory(encryption.NoopCrypter, crypter)
 	wrapped, err := c.Open(tempdir, snapshot)
@@ -133,12 +136,11 @@ func TestReadAllEntryIncorrectlyEncrypted(t *testing.T) {
 // The entry data and metadata are encryptd with the given encrypter, and a regular
 // WAL will see them as such.
 func TestSave(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 
 	crypter := &meowCrypter{}
 	c := NewWALFactory(crypter, encryption.NoopCrypter)
 	tempdir := createWithWAL(t, c, metadata, snapshot, entries)
-	defer os.RemoveAll(tempdir)
 
 	ogWAL, err := OriginalWAL.Open(tempdir, snapshot)
 	require.NoError(t, err)
@@ -159,18 +161,16 @@ func TestSave(t *testing.T) {
 
 // If encryption fails, saving will fail
 func TestSaveEncryptionFails(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 
-	tempdir, err := ioutil.TempDir("", "waltests")
-	require.NoError(t, err)
-	os.RemoveAll(tempdir)
-	defer os.RemoveAll(tempdir)
+	tempdir := t.TempDir()
+	walDir := filepath.Join(tempdir, "non_existing_dir") // non existing path
 
 	// fail encrypting one of the entries, but not the first one
 	c := NewWALFactory(&meowCrypter{encryptFailures: map[string]struct{}{
 		"Entry 3": {},
 	}}, nil)
-	wrapped, err := c.Create(tempdir, metadata)
+	wrapped, err := c.Create(walDir, metadata)
 	require.NoError(t, err)
 
 	require.NoError(t, wrapped.SaveSnapshot(snapshot))
@@ -180,7 +180,7 @@ func TestSaveEncryptionFails(t *testing.T) {
 	require.NoError(t, wrapped.Close())
 
 	// no entries are written at all
-	ogWAL, err := OriginalWAL.Open(tempdir, snapshot)
+	ogWAL, err := OriginalWAL.Open(walDir, snapshot)
 	require.NoError(t, err)
 	defer ogWAL.Close()
 
@@ -189,30 +189,28 @@ func TestSaveEncryptionFails(t *testing.T) {
 	require.Empty(t, ents)
 }
 
-// If the underlying WAL returns an error when opening or creating, the error
-// is propagated up.
-func TestCreateOpenInvalidDirFails(t *testing.T) {
+// If the underlying WAL returns an error when opening, the error is
+// propagated up.
+func TestOpenInvalidDirFails(t *testing.T) {
 	c := NewWALFactory(encryption.NoopCrypter, encryption.NoopCrypter)
 
-	_, err := c.Create("/not/existing/directory", []byte("metadata"))
-	require.Error(t, err)
-
-	tempDir, err := ioutil.TempDir("", "test-migrate")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempDir)
-
-	_, err = c.Open(tempDir, walpb.Snapshot{}) // invalid because no WAL file
+	tempDir := t.TempDir()
+	// using a subdirectory, as some of the code uses "filepath.Dir()"
+	// and we want to be sure we scope everything to inside the tempDir
+	// we created.
+	emptyDir := filepath.Join(tempDir, "empty_dir")
+	require.NoError(t, os.Mkdir(emptyDir, 0o700))
+	_, err := c.Open(emptyDir, walpb.Snapshot{}) // invalid because no WAL file
 	require.Error(t, err)
 }
 
 // A WAL can read what it wrote so long as it has a corresponding decrypter
 func TestSaveAndRead(t *testing.T) {
 	crypter := &meowCrypter{}
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 
 	c := NewWALFactory(crypter, crypter)
 	tempdir := createWithWAL(t, c, metadata, snapshot, entries)
-	defer os.RemoveAll(tempdir)
 
 	wrapped, err := c.Open(tempdir, snapshot)
 	require.NoError(t, err)
@@ -225,19 +223,32 @@ func TestSaveAndRead(t *testing.T) {
 }
 
 func TestReadRepairWAL(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 	tempdir := createWithWAL(t, OriginalWAL, metadata, snapshot, entries)
-	defer os.RemoveAll(tempdir)
 
 	// there should only be one WAL file in there - corrupt it
-	files, err := ioutil.ReadDir(tempdir)
+	files, err := os.ReadDir(tempdir)
 	require.NoError(t, err)
 	require.Len(t, files, 1)
 
-	fName := filepath.Join(tempdir, files[0].Name())
-	fileContents, err := ioutil.ReadFile(fName)
-	require.NoError(t, err)
-	require.NoError(t, ioutil.WriteFile(fName, fileContents[:200], files[0].Mode()))
+	// Corrupt the file by truncating it to replicate a broken state (partial
+	// write), but for this test, make sure that there's enough bytes left to
+	// read a record (24 bytes). The record size (recBytes) is calculated here;
+	//
+	// - https://github.com/etcd-io/etcd/blob/621cd7b9e5aa2ccf634b555e4ebe0037b8975066/server/wal/decoder.go#L83
+	// - https://github.com/etcd-io/etcd/blob/621cd7b9e5aa2ccf634b555e4ebe0037b8975066/server/wal/decoder.go#L122-L131
+	//
+	// Using a shorter length will make the test fail:
+	//
+	//	wal: max entry size limit exceeded, recBytes: 24, fileSize(200) - offset(184) - padBytes(0) = entryLimit(16)
+	//
+	// So the file should be >= 208 bytes.
+	//
+	// For further details, see:
+	//
+	// - https://github.com/etcd-io/etcd/commit/621cd7b9e5aa2ccf634b555e4ebe0037b8975066 / https://github.com/etcd-io/etcd/pull/14127 (backport of https://github.com/etcd-io/etcd/pull/14122)
+	// - https://github.com/etcd-io/etcd/issues/14114
+	require.NoError(t, os.Truncate(filepath.Join(tempdir, files[0].Name()), 300))
 
 	ogWAL, err := OriginalWAL.Open(tempdir, snapshot)
 	require.NoError(t, err)
@@ -249,10 +260,20 @@ func TestReadRepairWAL(t *testing.T) {
 	require.NoError(t, err)
 	require.Equal(t, metadata, waldata.Metadata)
 	require.NoError(t, ogWAL.Close())
+
+	// Also run with a file beyond repair.
+	tempdir = createWithWAL(t, OriginalWAL, metadata, snapshot, entries)
+	files, err = os.ReadDir(tempdir)
+	require.NoError(t, err)
+	require.Len(t, files, 1)
+	require.NoError(t, os.Truncate(filepath.Join(tempdir, files[0].Name()), 200))
+
+	_, _, err = ReadRepairWAL(context.Background(), tempdir, snapshot, OriginalWAL)
+	require.ErrorContains(t, err, "wal: max entry size limit exceeded")
 }
 
 func TestMigrateWALs(t *testing.T) {
-	metadata, entries, snapshot := makeWALData(1, 1)
+	metadata, entries, snapshot := makeWALData(1, 1, &confState)
 	coder := &meowCrypter{}
 	c := NewWALFactory(coder, coder)
 
@@ -261,16 +282,12 @@ func TestMigrateWALs(t *testing.T) {
 		dirs = make([]string, 2)
 	)
 
-	tempDir, err := ioutil.TempDir("", "test-migrate")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempDir)
-
+	tempDir := t.TempDir()
 	for i := range dirs {
-		dirs[i] = filepath.Join(tempDir, fmt.Sprintf("walDir%d", i))
+		dirs[i] = filepath.Join(tempDir, "walDir"+strconv.Itoa(i))
 	}
 
 	origDir := createWithWAL(t, OriginalWAL, metadata, snapshot, entries)
-	defer os.RemoveAll(origDir)
 
 	// original to new
 	oldDir := origDir
@@ -313,7 +330,7 @@ func TestMigrateWALs(t *testing.T) {
 	err = MigrateWALs(context.Background(), oldDir, newDir, OriginalWAL, c, walpb.Snapshot{})
 	require.Error(t, err)
 
-	subdirs, err := ioutil.ReadDir(tempDir)
+	subdirs, err := os.ReadDir(tempDir)
 	require.NoError(t, err)
 	require.Empty(t, subdirs)
 }
