@@ -3,20 +3,19 @@ package raft_test
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"strings"
 	"testing"
 	"time"
 
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/manager/state/raft"
-	"github.com/docker/swarmkit/manager/state/raft/storage"
-	raftutils "github.com/docker/swarmkit/manager/state/raft/testutils"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
-	"github.com/pivotal-golang/clock/fakeclock"
+	"code.cloudfoundry.org/clock/fakeclock"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/manager/state/raft"
+	"github.com/moby/swarmkit/v2/manager/state/raft/storage"
+	raftutils "github.com/moby/swarmkit/v2/manager/state/raft/testutils"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -41,7 +40,7 @@ func TestRaftSnapshot(t *testing.T) {
 
 	// None of the nodes should have snapshot files yet
 	for _, node := range nodes {
-		dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 		assert.NoError(t, err)
 		assert.Len(t, dirents, 0)
 	}
@@ -60,7 +59,7 @@ func TestRaftSnapshot(t *testing.T) {
 	// All nodes should now have a snapshot file
 	for nodeID, node := range nodes {
 		assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-			dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+			dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 			if err != nil {
 				return err
 			}
@@ -77,7 +76,7 @@ func TestRaftSnapshot(t *testing.T) {
 
 	// It should get a copy of the snapshot
 	assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-		dirents, err := ioutil.ReadDir(filepath.Join(nodes[4].StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(nodes[4].StateDir, "snap-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -113,7 +112,7 @@ func TestRaftSnapshot(t *testing.T) {
 	// All nodes should have a snapshot under a *different* name
 	for nodeID, node := range nodes {
 		assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-			dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+			dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 			if err != nil {
 				return err
 			}
@@ -158,7 +157,7 @@ func TestRaftSnapshotRestart(t *testing.T) {
 
 	// Remaining nodes shouldn't have snapshot files yet
 	for _, node := range []*raftutils.TestNode{nodes[1], nodes[2]} {
-		dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 		assert.NoError(t, err)
 		assert.Len(t, dirents, 0)
 	}
@@ -171,7 +170,7 @@ func TestRaftSnapshotRestart(t *testing.T) {
 	// Remaining nodes should now have a snapshot file
 	for nodeIdx, node := range []*raftutils.TestNode{nodes[1], nodes[2]} {
 		assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-			dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+			dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 			if err != nil {
 				return err
 			}
@@ -193,7 +192,7 @@ func TestRaftSnapshotRestart(t *testing.T) {
 
 	// New node should get a copy of the snapshot
 	assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-		dirents, err := ioutil.ReadDir(filepath.Join(nodes[5].StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(nodes[5].StateDir, "snap-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -203,7 +202,7 @@ func TestRaftSnapshotRestart(t *testing.T) {
 		return nil
 	}))
 
-	dirents, err := ioutil.ReadDir(filepath.Join(nodes[5].StateDir, "snap-v3-encrypted"))
+	dirents, err := os.ReadDir(filepath.Join(nodes[5].StateDir, "snap-v3-encrypted"))
 	assert.NoError(t, err)
 	assert.Len(t, dirents, 1)
 	raftutils.CheckValuesOnNodes(t, clockSource, map[uint64]*raftutils.TestNode{1: nodes[1], 2: nodes[2]}, nodeIDs[:5], values[:5])
@@ -287,7 +286,7 @@ func TestRaftSnapshotForceNewCluster(t *testing.T) {
 
 	// Nodes shouldn't have snapshot files yet
 	for _, node := range nodes {
-		dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 		assert.NoError(t, err)
 		assert.Len(t, dirents, 0)
 	}
@@ -299,7 +298,7 @@ func TestRaftSnapshotForceNewCluster(t *testing.T) {
 	// Nodes should now have a snapshot file
 	for nodeIdx, node := range nodes {
 		assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-			dirents, err := ioutil.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
+			dirents, err := os.ReadDir(filepath.Join(node.StateDir, "snap-v3-encrypted"))
 			if err != nil {
 				return err
 			}
@@ -350,7 +349,7 @@ func TestGCWAL(t *testing.T) {
 	// Snapshot should have been triggered just as the WAL rotated, so
 	// both WAL files should be preserved
 	assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-		dirents, err := ioutil.ReadDir(filepath.Join(nodes[1].StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(nodes[1].StateDir, "snap-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -358,7 +357,7 @@ func TestGCWAL(t *testing.T) {
 			return fmt.Errorf("expected 1 snapshot, found %d", len(dirents))
 		}
 
-		dirents, err = ioutil.ReadDir(filepath.Join(nodes[1].StateDir, "wal-v3-encrypted"))
+		dirents, err = os.ReadDir(filepath.Join(nodes[1].StateDir, "wal-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -390,7 +389,7 @@ func TestGCWAL(t *testing.T) {
 
 	// This time only one WAL file should be saved.
 	assert.NoError(t, testutils.PollFunc(clockSource, func() error {
-		dirents, err := ioutil.ReadDir(filepath.Join(nodes[1].StateDir, "snap-v3-encrypted"))
+		dirents, err := os.ReadDir(filepath.Join(nodes[1].StateDir, "snap-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -399,7 +398,7 @@ func TestGCWAL(t *testing.T) {
 			return fmt.Errorf("expected 1 snapshot, found %d", len(dirents))
 		}
 
-		dirents, err = ioutil.ReadDir(filepath.Join(nodes[1].StateDir, "wal-v3-encrypted"))
+		dirents, err = os.ReadDir(filepath.Join(nodes[1].StateDir, "wal-v3-encrypted"))
 		if err != nil {
 			return err
 		}
@@ -591,7 +590,7 @@ func TestRaftEncryptionKeyRotationWait(t *testing.T) {
 	// break snapshotting, and ensure that key rotation never finishes
 	tempSnapDir := filepath.Join(nodes[1].StateDir, "snap-backup")
 	require.NoError(t, os.Rename(snapDir, tempSnapDir))
-	require.NoError(t, ioutil.WriteFile(snapDir, []byte("this is no longer a directory"), 0644))
+	require.NoError(t, os.WriteFile(snapDir, []byte("this is no longer a directory"), 0o644))
 
 	nodes[1].KeyRotator.QueuePendingKey([]byte("key3"))
 	nodes[1].KeyRotator.RotationNotify() <- struct{}{}
