@@ -2,7 +2,6 @@ package testutils
 
 import (
 	"context"
-	"io/ioutil"
 	"net"
 	"os"
 	"reflect"
@@ -13,19 +12,19 @@ import (
 	"google.golang.org/grpc"
 
 	"code.cloudfoundry.org/clock/fakeclock"
-	etcdraft "github.com/coreos/etcd/raft"
-	"github.com/coreos/etcd/raft/raftpb"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/manager/health"
-	"github.com/docker/swarmkit/manager/state/raft"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/manager/health"
+	"github.com/moby/swarmkit/v2/manager/state/raft"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	etcdraft "go.etcd.io/etcd/raft/v3"
+	"go.etcd.io/etcd/raft/v3/raftpb"
 )
 
 // TestNode represents a raft test node
@@ -271,7 +270,7 @@ func NewNode(t *testing.T, clockSource *fakeclock.FakeClock, tc *cautils.TestCA,
 
 	cfg := raft.DefaultNodeConfig()
 
-	stateDir, err := ioutil.TempDir("", t.Name())
+	stateDir, err := os.MkdirTemp("", t.Name())
 	require.NoError(t, err, "can't create temporary state directory")
 
 	keyRotator := NewSimpleKeyRotator(raft.EncryptionKeys{CurrentDEK: []byte("current")})
