@@ -2,17 +2,17 @@ package watchapi
 
 import (
 	"context"
-	"io/ioutil"
+	"io"
 	"net"
 	"os"
 	"testing"
 	"time"
 
-	"github.com/docker/swarmkit/api"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/manager/state/store"
-	stateutils "github.com/docker/swarmkit/manager/state/testutils"
-	"github.com/sirupsen/logrus"
+	"github.com/moby/swarmkit/v2/api"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	stateutils "github.com/moby/swarmkit/v2/manager/state/testutils"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
@@ -52,7 +52,7 @@ func newTestServer(t *testing.T) *testServer {
 
 	require.NoError(t, ts.Server.Start(context.Background()))
 
-	temp, err := ioutil.TempFile("", "test-socket")
+	temp, err := os.CreateTemp("", "test-socket")
 	assert.NoError(t, err)
 	assert.NoError(t, temp.Close())
 	assert.NoError(t, os.Remove(temp.Name()))
@@ -101,6 +101,6 @@ func createNode(t *testing.T, ts *testServer, id string, role api.NodeRole, memb
 }
 
 func init() {
-	grpclog.SetLoggerV2(grpclog.NewLoggerV2(ioutil.Discard, ioutil.Discard, ioutil.Discard))
-	logrus.SetOutput(ioutil.Discard)
+	grpclog.SetLoggerV2(grpclog.NewLoggerV2(io.Discard, io.Discard, io.Discard))
+	log.L.Logger.SetOutput(io.Discard)
 }
