@@ -6,40 +6,33 @@ import (
 	"crypto/x509"
 	"encoding/pem"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
+	"strconv"
 	"strings"
 	"testing"
 	"time"
 
 	"github.com/cloudflare/cfssl/helpers"
-	"github.com/docker/swarmkit/agent"
-	agentutils "github.com/docker/swarmkit/agent/testutils"
-	"github.com/docker/swarmkit/api"
-	"github.com/docker/swarmkit/ca"
-	"github.com/docker/swarmkit/ca/keyutils"
-	cautils "github.com/docker/swarmkit/ca/testutils"
-	"github.com/docker/swarmkit/identity"
-	"github.com/docker/swarmkit/log"
-	"github.com/docker/swarmkit/manager/state/store"
-	"github.com/docker/swarmkit/testutils"
+	"github.com/moby/swarmkit/v2/agent"
+	agentutils "github.com/moby/swarmkit/v2/agent/testutils"
+	"github.com/moby/swarmkit/v2/api"
+	"github.com/moby/swarmkit/v2/ca"
+	"github.com/moby/swarmkit/v2/ca/keyutils"
+	cautils "github.com/moby/swarmkit/v2/ca/testutils"
+	"github.com/moby/swarmkit/v2/identity"
+	"github.com/moby/swarmkit/v2/log"
+	"github.com/moby/swarmkit/v2/manager/state/store"
+	"github.com/moby/swarmkit/v2/testutils"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/require"
 )
 
-func getLoggingContext(t *testing.T) context.Context {
-	return log.WithLogger(context.Background(), log.L.WithField("test", t.Name()))
-}
-
 // If there is nothing on disk and no join addr, we create a new CA and a new set of TLS certs.
 // If AutoLockManagers is enabled, the TLS key is encrypted with a randomly generated lock key.
 func TestLoadSecurityConfigNewNode(t *testing.T) {
 	for _, autoLockManagers := range []bool{true, false} {
-		tempdir, err := ioutil.TempDir("", "test-new-node")
-		require.NoError(t, err)
-		defer os.RemoveAll(tempdir)
-
+		tempdir := t.TempDir()
 		paths := ca.NewConfigPaths(filepath.Join(tempdir, "certificates"))
 
 		node, err := New(&Config{
@@ -65,10 +58,7 @@ func TestLoadSecurityConfigNewNode(t *testing.T) {
 // If there's only a root CA on disk (no TLS certs), and no join addr, we create a new CA
 // and a new set of TLS certs.  Similarly if there's only a TLS cert and key, and no CA.
 func TestLoadSecurityConfigPartialCertsOnDisk(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-new-node")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tempdir, "certificates"))
 	rootCA, err := ca.CreateRootCA(ca.DefaultRootCN)
 	require.NoError(t, err)
@@ -111,10 +101,7 @@ func TestLoadSecurityConfigPartialCertsOnDisk(t *testing.T) {
 // If there are CAs and TLS certs on disk, it tries to load and fails if there
 // are any errors, even if a join token is provided.
 func TestLoadSecurityConfigLoadFromDisk(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-load-node-tls")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tempdir, "certificates"))
 
 	tc := cautils.NewTestCA(t)
@@ -188,10 +175,7 @@ func TestLoadSecurityConfigLoadFromDisk(t *testing.T) {
 // join server. If there is a CA, it is just loaded from disk.  The TLS key and
 // cert are also downloaded.
 func TestLoadSecurityConfigDownloadAllCerts(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-join-node")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tempdir, "certificates"))
 
 	// join addr is invalid
@@ -227,13 +211,13 @@ func TestLoadSecurityConfigDownloadAllCerts(t *testing.T) {
 	// know if it gets replaced
 	require.NoError(t, os.Remove(paths.Node.Cert))
 	require.NoError(t, os.Remove(paths.Node.Key))
-	certBytes, err := ioutil.ReadFile(paths.RootCA.Cert)
+	certBytes, err := os.ReadFile(paths.RootCA.Cert)
 	require.NoError(t, err)
 	pemBlock, _ := pem.Decode(certBytes)
 	require.NotNil(t, pemBlock)
 	pemBlock.Headers["marked"] = "true"
 	certBytes = pem.EncodeToMemory(pemBlock)
-	require.NoError(t, ioutil.WriteFile(paths.RootCA.Cert, certBytes, 0644))
+	require.NoError(t, os.WriteFile(paths.RootCA.Cert, certBytes, 0o644))
 
 	// also make sure the new set gets downloaded and written to disk with a passphrase
 	// by updating the memory store with manager autolock on and an unlock key
@@ -265,7 +249,7 @@ func TestLoadSecurityConfigDownloadAllCerts(t *testing.T) {
 	cancel()
 
 	// make sure the CA cert has not been replaced
-	readCertBytes, err := ioutil.ReadFile(paths.RootCA.Cert)
+	readCertBytes, err := os.ReadFile(paths.RootCA.Cert)
 	require.NoError(t, err)
 	require.Equal(t, certBytes, readCertBytes)
 
@@ -279,10 +263,7 @@ func TestLoadSecurityConfigDownloadAllCerts(t *testing.T) {
 // If there is nothing on disk and no join addr, and FIPS is enabled, we create a cluster whose
 // ID starts with 'FIPS.'
 func TestLoadSecurityConfigNodeFIPSCreateCluster(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-security-config-fips-new-cluster")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tempdir, "certificates"))
 
 	tc := cautils.NewTestCA(t)
@@ -305,58 +286,54 @@ func TestLoadSecurityConfigNodeFIPSCreateCluster(t *testing.T) {
 // If FIPS is enabled and there is a join address, the cluster ID is whatever the CA set
 // the cluster ID to.
 func TestLoadSecurityConfigNodeFIPSJoinCluster(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-security-config-fips-join-cluster")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
-	certDir := filepath.Join(tempdir, "certificates")
-	paths := ca.NewConfigPaths(certDir)
-
 	for _, fips := range []bool{true, false} {
-		require.NoError(t, os.RemoveAll(certDir))
+		fips := fips
+		t.Run("fips="+strconv.FormatBool(fips), func(t *testing.T) {
+			t.Parallel()
+			tempdir := t.TempDir()
+			certDir := filepath.Join(tempdir, "certificates")
+			paths := ca.NewConfigPaths(certDir)
 
-		var tc *cautils.TestCA
-		if fips {
-			tc = cautils.NewFIPSTestCA(t)
-		} else {
-			tc = cautils.NewTestCA(t)
-		}
-		defer tc.Stop()
+			var tc *cautils.TestCA
+			if fips {
+				tc = cautils.NewFIPSTestCA(t)
+			} else {
+				tc = cautils.NewTestCA(t)
+			}
+			defer tc.Stop()
 
-		peer, err := tc.ConnBroker.Remotes().Select()
-		require.NoError(t, err)
+			peer, err := tc.ConnBroker.Remotes().Select()
+			require.NoError(t, err)
 
-		node, err := New(&Config{
-			StateDir:  tempdir,
-			JoinAddr:  peer.Addr,
-			JoinToken: tc.ManagerToken,
-			FIPS:      true,
+			node, err := New(&Config{
+				StateDir:  tempdir,
+				JoinAddr:  peer.Addr,
+				JoinToken: tc.ManagerToken,
+				FIPS:      true,
+			})
+			require.NoError(t, err)
+			securityConfig, cancel, err := node.loadSecurityConfig(tc.Context, paths)
+			require.NoError(t, err)
+			defer cancel()
+			require.NotNil(t, securityConfig)
+			require.Equal(t, fips, strings.HasPrefix(securityConfig.ClientTLSCreds.Organization(), "FIPS."))
 		})
-		require.NoError(t, err)
-		securityConfig, cancel, err := node.loadSecurityConfig(tc.Context, paths)
-		require.NoError(t, err)
-		defer cancel()
-		require.NotNil(t, securityConfig)
-		require.Equal(t, fips, strings.HasPrefix(securityConfig.ClientTLSCreds.Organization(), "FIPS."))
 	}
 }
 
 // If the certificate specifies that the cluster requires FIPS mode, loading the security
 // config will fail if the node is not FIPS enabled.
 func TestLoadSecurityConfigRespectsFIPSCert(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-security-config-fips-cert-on-disk")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
 	tc := cautils.NewFIPSTestCA(t)
 	defer tc.Stop()
 
+	tempdir := t.TempDir()
 	certDir := filepath.Join(tempdir, "certificates")
-	require.NoError(t, os.Mkdir(certDir, 0700))
+	require.NoError(t, os.Mkdir(certDir, 0o700))
 	paths := ca.NewConfigPaths(certDir)
 
 	// copy certs and keys from the test CA using a hard link
-	_, err = tc.WriteNewNodeConfig(ca.ManagerRole)
+	_, err := tc.WriteNewNodeConfig(ca.ManagerRole)
 	require.NoError(t, err)
 	require.NoError(t, os.Link(tc.Paths.Node.Cert, paths.Node.Cert))
 	require.NoError(t, os.Link(tc.Paths.Node.Key, paths.Node.Key))
@@ -383,18 +360,15 @@ func TestLoadSecurityConfigRespectsFIPSCert(t *testing.T) {
 // the cluster requires fips, then loading the security config will fail.  However, if
 // there are already certs on disk, it will load them and ignore the join token.
 func TestLoadSecurityConfigNonFIPSNodeJoinCluster(t *testing.T) {
-	tempdir, err := ioutil.TempDir("", "test-security-config-nonfips-join-cluster")
-	require.NoError(t, err)
-	defer os.RemoveAll(tempdir)
-
+	tempdir := t.TempDir()
 	certDir := filepath.Join(tempdir, "certificates")
-	require.NoError(t, os.Mkdir(certDir, 0700))
+	require.NoError(t, os.Mkdir(certDir, 0o700))
 	paths := ca.NewConfigPaths(certDir)
 
 	tc := cautils.NewTestCA(t)
 	defer tc.Stop()
 	// copy certs and keys from the test CA using a hard link
-	_, err = tc.WriteNewNodeConfig(ca.ManagerRole)
+	_, err := tc.WriteNewNodeConfig(ca.ManagerRole)
 	require.NoError(t, err)
 	require.NoError(t, os.Link(tc.Paths.Node.Cert, paths.Node.Cert))
 	require.NoError(t, os.Link(tc.Paths.Node.Key, paths.Node.Key))
@@ -433,9 +407,7 @@ func TestLoadSecurityConfigNonFIPSNodeJoinCluster(t *testing.T) {
 }
 
 func TestManagerRespectsDispatcherRootCAUpdate(t *testing.T) {
-	tmpDir, err := ioutil.TempDir("", "manager-root-ca-update")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
+	tmpDir := t.TempDir()
 
 	// don't bother with a listening socket
 	cAddr := filepath.Join(tmpDir, "control.sock")
@@ -481,7 +453,7 @@ func TestManagerRespectsDispatcherRootCAUpdate(t *testing.T) {
 	// the node root CA certificates have changed now
 	time.Sleep(250 * time.Millisecond)
 	certPath := filepath.Join(tmpDir, certDirectory, "swarm-root-ca.crt")
-	caCerts, err := ioutil.ReadFile(certPath)
+	caCerts, err := os.ReadFile(certPath)
 	require.NoError(t, err)
 	require.NotEqual(t, currentCACerts, caCerts)
 
@@ -489,9 +461,7 @@ func TestManagerRespectsDispatcherRootCAUpdate(t *testing.T) {
 }
 
 func TestAgentRespectsDispatcherRootCAUpdate(t *testing.T) {
-	tmpDir, err := ioutil.TempDir("", "manager-root-ca-update")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
+	tmpDir := t.TempDir()
 
 	// bootstrap worker TLS certificates
 	paths := ca.NewConfigPaths(filepath.Join(tmpDir, certDirectory))
@@ -526,7 +496,7 @@ func TestAgentRespectsDispatcherRootCAUpdate(t *testing.T) {
 		require.FailNow(t, "node did not ready in time")
 	}
 
-	currentCACerts, err := ioutil.ReadFile(paths.RootCA.Cert)
+	currentCACerts, err := os.ReadFile(paths.RootCA.Cert)
 	require.NoError(t, err)
 	parsedCerts, err := helpers.ParseCertificatesPEM(currentCACerts)
 	require.NoError(t, err)
@@ -538,7 +508,7 @@ func TestAgentRespectsDispatcherRootCAUpdate(t *testing.T) {
 	}
 
 	require.NoError(t, testutils.PollFuncWithTimeout(nil, func() error {
-		caCerts, err := ioutil.ReadFile(paths.RootCA.Cert)
+		caCerts, err := os.ReadFile(paths.RootCA.Cert)
 		require.NoError(t, err)
 		if bytes.Equal(currentCACerts, caCerts) {
 			return errors.New("new certificates have not been replaced yet")
@@ -557,10 +527,7 @@ func TestAgentRespectsDispatcherRootCAUpdate(t *testing.T) {
 }
 
 func TestCertRenewals(t *testing.T) {
-	tmpDir, err := ioutil.TempDir("", "no-top-level-role")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
-
+	tmpDir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tmpDir, "certificates"))
 
 	// don't bother with a listening socket
@@ -581,7 +548,7 @@ func TestCertRenewals(t *testing.T) {
 		require.FailNow(t, "node did not ready in time")
 	}
 
-	currentNodeCert, err := ioutil.ReadFile(paths.Node.Cert)
+	currentNodeCert, err := os.ReadFile(paths.Node.Cert)
 	require.NoError(t, err)
 
 	// Fake an update from the dispatcher. Make sure the Role field is
@@ -597,7 +564,7 @@ func TestCertRenewals(t *testing.T) {
 
 	time.Sleep(500 * time.Millisecond)
 
-	nodeCert, err := ioutil.ReadFile(paths.Node.Cert)
+	nodeCert, err := os.ReadFile(paths.Node.Cert)
 	require.NoError(t, err)
 	if !bytes.Equal(currentNodeCert, nodeCert) {
 		t.Fatal("Certificate should not have been renewed")
@@ -615,7 +582,7 @@ func TestCertRenewals(t *testing.T) {
 	}
 
 	require.NoError(t, testutils.PollFuncWithTimeout(nil, func() error {
-		nodeCert, err := ioutil.ReadFile(paths.Node.Cert)
+		nodeCert, err := os.ReadFile(paths.Node.Cert)
 		require.NoError(t, err)
 		if bytes.Equal(currentNodeCert, nodeCert) {
 			return errors.New("certificate has not been replaced yet")
@@ -628,10 +595,7 @@ func TestCertRenewals(t *testing.T) {
 }
 
 func TestManagerFailedStartup(t *testing.T) {
-	tmpDir, err := ioutil.TempDir("", "manager-root-ca-update")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
-
+	tmpDir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tmpDir, certDirectory))
 
 	rootCA, err := ca.CreateRootCA(ca.DefaultRootCN)
@@ -669,11 +633,7 @@ func TestManagerFailedStartup(t *testing.T) {
 
 // TestFIPSConfiguration ensures that new keys will be stored in PKCS8 format.
 func TestFIPSConfiguration(t *testing.T) {
-	ctx := getLoggingContext(t)
-	tmpDir, err := ioutil.TempDir("", "fips")
-	require.NoError(t, err)
-	defer os.RemoveAll(tmpDir)
-
+	tmpDir := t.TempDir()
 	paths := ca.NewConfigPaths(filepath.Join(tmpDir, "certificates"))
 
 	// don't bother with a listening socket
@@ -686,6 +646,8 @@ func TestFIPSConfiguration(t *testing.T) {
 	}
 	node, err := New(cfg)
 	require.NoError(t, err)
+
+	ctx := log.WithLogger(context.Background(), log.L.WithField("test", t.Name()))
 	require.NoError(t, node.Start(ctx))
 	defer func() {
 		require.NoError(t, node.Stop(ctx))
@@ -697,7 +659,7 @@ func TestFIPSConfiguration(t *testing.T) {
 		require.FailNow(t, "node did not ready in time")
 	}
 
-	nodeKey, err := ioutil.ReadFile(paths.Node.Key)
+	nodeKey, err := os.ReadFile(paths.Node.Key)
 	require.NoError(t, err)
 	pemBlock, _ := pem.Decode(nodeKey)
 	require.NotNil(t, pemBlock)
