@@ -2,7 +2,7 @@ package version
 
 // Package is the overall, canonical project import path under which the
 // package was built.
-var Package = "github.com/docker/swarmkit"
+var Package = "github.com/moby/swarmkit/v2"
 
 // Version indicates which version of the binary is running. This is set to
 // the latest release tag by hand, always suffixed by "+unknown". During
